@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2019 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -122,51 +122,64 @@ extern const fcml_cstring M_CLTD;
 extern const fcml_cstring M_CLTQ;
 extern const fcml_cstring M_CLTS;
 extern const fcml_cstring M_CMC;
-extern const fcml_cstring M_CMOVO;
-extern const fcml_cstring M_CMOVNO;
-extern const fcml_cstring M_CMOVB;
-extern const fcml_cstring M_CMOVNB;
-extern const fcml_cstring M_CMOVE;
-extern const fcml_cstring M_CMOVNE;
-extern const fcml_cstring M_CMOVBE;
-extern const fcml_cstring M_CMOVNBE;
-extern const fcml_cstring M_CMOVS;
-extern const fcml_cstring M_CMOVNS;
-extern const fcml_cstring M_CMOVP;
-extern const fcml_cstring M_CMOVNP;
-extern const fcml_cstring M_CMOVL;
-extern const fcml_cstring M_CMOVNL;
-extern const fcml_cstring M_CMOVLE;
-extern const fcml_cstring M_CMOVNLE;
-extern const fcml_cstring M_CMOVNAE;
-extern const fcml_cstring M_CMOVAE;
-extern const fcml_cstring M_CMOVZ;
-extern const fcml_cstring M_CMOVNZ;
-extern const fcml_cstring M_CMOVNA;
 extern const fcml_cstring M_CMOVA;
+extern const fcml_cstring M_CMOVAE;
+extern const fcml_cstring M_CMOVB;
+extern const fcml_cstring M_CMOVBE;
+extern const fcml_cstring M_CMOVC;
+extern const fcml_cstring M_CMOVENE;
+extern const fcml_cstring M_CMOVG;
+extern const fcml_cstring M_CMOVGE;
+extern const fcml_cstring M_CMOVL;
+extern const fcml_cstring M_CMOVLE;
+extern const fcml_cstring M_CMOVNA;
+extern const fcml_cstring M_CMOVNAE;
+extern const fcml_cstring M_CMOVNB;
+extern const fcml_cstring M_CMOVNBE;
+extern const fcml_cstring M_CMOVNC;
+extern const fcml_cstring M_CMOVNG;
+extern const fcml_cstring M_CMOVNGE;
+extern const fcml_cstring M_CMOVNL;
+extern const fcml_cstring M_CMOVNLE;
+extern const fcml_cstring M_CMOVNO;
+extern const fcml_cstring M_CMOVNP;
+extern const fcml_cstring M_CMOVNS;
+extern const fcml_cstring M_CMOVNZ;
+extern const fcml_cstring M_CMOVO;
+extern const fcml_cstring M_CMOVP;
 extern const fcml_cstring M_CMOVPE;
 extern const fcml_cstring M_CMOVPO;
-extern const fcml_cstring M_CMOVNGE;
-extern const fcml_cstring M_CMOVGE;
-extern const fcml_cstring M_CMOVNG;
-extern const fcml_cstring M_CMOVG;
-extern const fcml_cstring M_CMOVC;
-extern const fcml_cstring M_CMOVNC;
+extern const fcml_cstring M_CMOVS;
+extern const fcml_cstring M_CMOVZ;
 extern const fcml_cstring M_CMP;
 extern const fcml_cstring M_CMPB;
+extern const fcml_cstring M_CMPEQPD;
+extern const fcml_cstring M_CMPEQPS;
 extern const fcml_cstring M_CMPEQSD;
 extern const fcml_cstring M_CMPEQSS;
 extern const fcml_cstring M_CMPL;
+extern const fcml_cstring M_CMPLEPD;
+extern const fcml_cstring M_CMPLEPS;
 extern const fcml_cstring M_CMPLESD;
 extern const fcml_cstring M_CMPLESS;
+extern const fcml_cstring M_CMPLTPD;
+extern const fcml_cstring M_CMPLTPS;
 extern const fcml_cstring M_CMPLTSD;
 extern const fcml_cstring M_CMPLTSS;
+extern const fcml_cstring M_CMPNEQPD;
+extern const fcml_cstring M_CMPNEQPS;
 extern const fcml_cstring M_CMPNEQSD;
 extern const fcml_cstring M_CMPNEQSS;
+extern const fcml_cstring M_CMPNLEPD;
+extern const fcml_cstring M_CMPNLEPS;
 extern const fcml_cstring M_CMPNLESD;
 extern const fcml_cstring M_CMPNLESS;
+extern const fcml_cstring M_CMPNLTPD;
+extern const fcml_cstring M_CMPNLTPS;
 extern const fcml_cstring M_CMPNLTSD;
 extern const fcml_cstring M_CMPNLTSS;
+extern const fcml_cstring M_CMPORDPD;
+extern const fcml_cstring M_CMPORDPS;
 extern const fcml_cstring M_CMPORDSD;
 extern const fcml_cstring M_CMPORDSS;
 extern const fcml_cstring M_CMPPD;
@@ -178,6 +191,8 @@ extern const fcml_cstring M_CMPSL;
 extern const fcml_cstring M_CMPSQ;
 extern const fcml_cstring M_CMPSS;
 extern const fcml_cstring M_CMPSW;
+extern const fcml_cstring M_CMPUNORDPD;
+extern const fcml_cstring M_CMPUNORDPS;
 extern const fcml_cstring M_CMPUNORDSD;
 extern const fcml_cstring M_CMPUNORDSS;
 extern const fcml_cstring M_CMPW;
@@ -423,42 +438,89 @@ extern const fcml_cstring M_INVVPID;
 extern const fcml_cstring M_IRET;
 extern const fcml_cstring M_IRETQ;
 extern const fcml_cstring M_IRETW;
-extern const fcml_cstring M_JO;
-extern const fcml_cstring M_JNO;
-extern const fcml_cstring M_JB;
-extern const fcml_cstring M_JNB;
-extern const fcml_cstring M_JE;
-extern const fcml_cstring M_JNE;
-extern const fcml_cstring M_JBE;
-extern const fcml_cstring M_JNBE;
-extern const fcml_cstring M_JS;
-extern const fcml_cstring M_JNS;
-extern const fcml_cstring M_JP;
-extern const fcml_cstring M_JNP;
-extern const fcml_cstring M_JL;
-extern const fcml_cstring M_JNL;
-extern const fcml_cstring M_JLE;
-extern const fcml_cstring M_JNLE;
-extern const fcml_cstring M_JNAE;
-extern const fcml_cstring M_JAE;
-extern const fcml_cstring M_JZ;
-extern const fcml_cstring M_JNZ;
-extern const fcml_cstring M_JNA;
 extern const fcml_cstring M_JA;
-extern const fcml_cstring M_JPE;
-extern const fcml_cstring M_JPO;
-extern const fcml_cstring M_JNGE;
-extern const fcml_cstring M_JGE;
-extern const fcml_cstring M_JNG;
-extern const fcml_cstring M_JG;
+extern const fcml_cstring M_JAE;
+extern const fcml_cstring M_JB;
+extern const fcml_cstring M_JBE;
 extern const fcml_cstring M_JC;
-extern const fcml_cstring M_JNC;
 extern const fcml_cstring M_JCXZ;
 extern const fcml_cstring M_JECXZ;
+extern const fcml_cstring M_JENE;
+extern const fcml_cstring M_JG;
+extern const fcml_cstring M_JGE;
+extern const fcml_cstring M_JL;
+extern const fcml_cstring M_JLE;
 extern const fcml_cstring M_JMP;
 extern const fcml_cstring M_JMPQ;
 extern const fcml_cstring M_JMPW;
+extern const fcml_cstring M_JNA;
+extern const fcml_cstring M_JNAE;
+extern const fcml_cstring M_JNB;
+extern const fcml_cstring M_JNBE;
+extern const fcml_cstring M_JNC;
+extern const fcml_cstring M_JNG;
+extern const fcml_cstring M_JNGE;
+extern const fcml_cstring M_JNL;
+extern const fcml_cstring M_JNLE;
+extern const fcml_cstring M_JNO;
+extern const fcml_cstring M_JNP;
+extern const fcml_cstring M_JNS;
+extern const fcml_cstring M_JNZ;
+extern const fcml_cstring M_JO;
+extern const fcml_cstring M_JP;
+extern const fcml_cstring M_JPE;
+extern const fcml_cstring M_JPO;
 extern const fcml_cstring M_JRCXZ;
+extern const fcml_cstring M_JS;
+extern const fcml_cstring M_JZ;
+extern const fcml_cstring M_KADDB;
+extern const fcml_cstring M_KADDD;
+extern const fcml_cstring M_KADDQ;
+extern const fcml_cstring M_KADDW;
+extern const fcml_cstring M_KANDB;
+extern const fcml_cstring M_KANDD;
+extern const fcml_cstring M_KANDNB;
+extern const fcml_cstring M_KANDND;
+extern const fcml_cstring M_KANDNQ;
+extern const fcml_cstring M_KANDNW;
+extern const fcml_cstring M_KANDQ;
+extern const fcml_cstring M_KANDW;
+extern const fcml_cstring M_KMOVB;
+extern const fcml_cstring M_KMOVD;
+extern const fcml_cstring M_KMOVQ;
+extern const fcml_cstring M_KMOVW;
+extern const fcml_cstring M_KNOTB;
+extern const fcml_cstring M_KNOTD;
+extern const fcml_cstring M_KNOTQ;
+extern const fcml_cstring M_KNOTW;
+extern const fcml_cstring M_KORB;
+extern const fcml_cstring M_KORD;
+extern const fcml_cstring M_KORQ;
+extern const fcml_cstring M_KORTESTB;
+extern const fcml_cstring M_KORTESTD;
+extern const fcml_cstring M_KORTESTQ;
+extern const fcml_cstring M_KORTESTW;
+extern const fcml_cstring M_KORW;
+extern const fcml_cstring M_KSHIFTLB;
+extern const fcml_cstring M_KSHIFTLD;
+extern const fcml_cstring M_KSHIFTLQ;
+extern const fcml_cstring M_KSHIFTLW;
+extern const fcml_cstring M_KSHIFTRB;
+extern const fcml_cstring M_KSHIFTRD;
+extern const fcml_cstring M_KSHIFTRQ;
+extern const fcml_cstring M_KSHIFTRW;
+extern const fcml_cstring M_KTESTB;
+extern const fcml_cstring M_KTESTD;
+extern const fcml_cstring M_KTESTQ;
+extern const fcml_cstring M_KTESTW;
+extern const fcml_cstring M_KXNORB;
+extern const fcml_cstring M_KXNORD;
+extern const fcml_cstring M_KXNORQ;
+extern const fcml_cstring M_KXNORW;
+extern const fcml_cstring M_KXORB;
+extern const fcml_cstring M_KXORD;
+extern const fcml_cstring M_KXORQ;
+extern const fcml_cstring M_KXORW;
 extern const fcml_cstring M_LAHF;
 extern const fcml_cstring M_LAR;
 extern const fcml_cstring M_LCALL;
@@ -732,6 +794,7 @@ extern const fcml_cstring M_PREFETCHT0;
 extern const fcml_cstring M_PREFETCHT1;
 extern const fcml_cstring M_PREFETCHT2;
 extern const fcml_cstring M_PREFETCHW;
+extern const fcml_cstring M_PREFETCHWT1;
 extern const fcml_cstring M_PSADBW;
 extern const fcml_cstring M_PSHUFB;
 extern const fcml_cstring M_PSHUFD;
@@ -843,36 +906,35 @@ extern const fcml_cstring M_SCASB;
 extern const fcml_cstring M_SCASL;
 extern const fcml_cstring M_SCASQ;
 extern const fcml_cstring M_SCASW;
-extern const fcml_cstring M_SETO;
-extern const fcml_cstring M_SETNO;
-extern const fcml_cstring M_SETB;
-extern const fcml_cstring M_SETNB;
-extern const fcml_cstring M_SETE;
-extern const fcml_cstring M_SETNE;
-extern const fcml_cstring M_SETBE;
-extern const fcml_cstring M_SETNBE;
-extern const fcml_cstring M_SETS;
-extern const fcml_cstring M_SETNS;
-extern const fcml_cstring M_SETP;
-extern const fcml_cstring M_SETNP;
-extern const fcml_cstring M_SETL;
-extern const fcml_cstring M_SETNL;
-extern const fcml_cstring M_SETLE;
-extern const fcml_cstring M_SETNLE;
-extern const fcml_cstring M_SETNAE;
-extern const fcml_cstring M_SETAE;
-extern const fcml_cstring M_SETZ;
-extern const fcml_cstring M_SETNZ;
-extern const fcml_cstring M_SETNA;
 extern const fcml_cstring M_SETA;
+extern const fcml_cstring M_SETAE;
+extern const fcml_cstring M_SETB;
+extern const fcml_cstring M_SETBE;
+extern const fcml_cstring M_SETC;
+extern const fcml_cstring M_SETENE;
+extern const fcml_cstring M_SETG;
+extern const fcml_cstring M_SETGE;
+extern const fcml_cstring M_SETL;
+extern const fcml_cstring M_SETLE;
+extern const fcml_cstring M_SETNA;
+extern const fcml_cstring M_SETNAE;
+extern const fcml_cstring M_SETNB;
+extern const fcml_cstring M_SETNBE;
+extern const fcml_cstring M_SETNC;
+extern const fcml_cstring M_SETNG;
+extern const fcml_cstring M_SETNGE;
+extern const fcml_cstring M_SETNL;
+extern const fcml_cstring M_SETNLE;
+extern const fcml_cstring M_SETNO;
+extern const fcml_cstring M_SETNP;
+extern const fcml_cstring M_SETNS;
+extern const fcml_cstring M_SETNZ;
+extern const fcml_cstring M_SETO;
+extern const fcml_cstring M_SETP;
 extern const fcml_cstring M_SETPE;
 extern const fcml_cstring M_SETPO;
-extern const fcml_cstring M_SETNGE;
-extern const fcml_cstring M_SETGE;
-extern const fcml_cstring M_SETNG;
-extern const fcml_cstring M_SETG;
-extern const fcml_cstring M_SETC;
-extern const fcml_cstring M_SETNC;
+extern const fcml_cstring M_SETS;
+extern const fcml_cstring M_SETZ;
 extern const fcml_cstring M_SFENCE;
 extern const fcml_cstring M_SGDT;
 extern const fcml_cstring M_SHL;
@@ -941,6 +1003,10 @@ extern const fcml_cstring M_UNPCKHPD;
 extern const fcml_cstring M_UNPCKHPS;
 extern const fcml_cstring M_UNPCKLPD;
 extern const fcml_cstring M_UNPCKLPS;
+extern const fcml_cstring M_V4FMADDPS;
+extern const fcml_cstring M_V4FMADDSS;
+extern const fcml_cstring M_V4FNMADDPS;
+extern const fcml_cstring M_V4FNMADDSS;
 extern const fcml_cstring M_VADDPD;
 extern const fcml_cstring M_VADDPS;
 extern const fcml_cstring M_VADDSD;
@@ -953,110 +1019,227 @@ extern const fcml_cstring M_VAESENC;
 extern const fcml_cstring M_VAESENCLAST;
 extern const fcml_cstring M_VAESIMC;
 extern const fcml_cstring M_VAESKEYGENASSIST;
+extern const fcml_cstring M_VALIGND;
+extern const fcml_cstring M_VALIGNQ;
 extern const fcml_cstring M_VANDNPD;
 extern const fcml_cstring M_VANDNPS;
 extern const fcml_cstring M_VANDPD;
 extern const fcml_cstring M_VANDPS;
+extern const fcml_cstring M_VBLENDMPD;
+extern const fcml_cstring M_VBLENDMPS;
 extern const fcml_cstring M_VBLENDPD;
 extern const fcml_cstring M_VBLENDPS;
 extern const fcml_cstring M_VBLENDVPD;
 extern const fcml_cstring M_VBLENDVPS;
 extern const fcml_cstring M_VBROADCASTF128;
+extern const fcml_cstring M_VBROADCASTF32X2;
+extern const fcml_cstring M_VBROADCASTF32X4;
+extern const fcml_cstring M_VBROADCASTF32X8;
+extern const fcml_cstring M_VBROADCASTF64X2;
+extern const fcml_cstring M_VBROADCASTF64X4;
 extern const fcml_cstring M_VBROADCASTI128;
+extern const fcml_cstring M_VBROADCASTI32X2;
+extern const fcml_cstring M_VBROADCASTI32X4;
+extern const fcml_cstring M_VBROADCASTI32X8;
+extern const fcml_cstring M_VBROADCASTI64X2;
+extern const fcml_cstring M_VBROADCASTI64X4;
 extern const fcml_cstring M_VBROADCASTSD;
 extern const fcml_cstring M_VBROADCASTSS;
+extern const fcml_cstring M_VCMPEQ_OSPD;
+extern const fcml_cstring M_VCMPEQ_OSPS;
 extern const fcml_cstring M_VCMPEQ_OSSD;
 extern const fcml_cstring M_VCMPEQ_OSSS;
-extern const fcml_cstring M_VCMPEQSD;
-extern const fcml_cstring M_VCMPEQSS;
+extern const fcml_cstring M_VCMPEQ_UQPD;
+extern const fcml_cstring M_VCMPEQ_UQPS;
 extern const fcml_cstring M_VCMPEQ_UQSD;
 extern const fcml_cstring M_VCMPEQ_UQSS;
+extern const fcml_cstring M_VCMPEQ_USPD;
+extern const fcml_cstring M_VCMPEQ_USPS;
 extern const fcml_cstring M_VCMPEQ_USSD;
 extern const fcml_cstring M_VCMPEQ_USSS;
+extern const fcml_cstring M_VCMPEQPD;
+extern const fcml_cstring M_VCMPEQPS;
+extern const fcml_cstring M_VCMPEQSD;
+extern const fcml_cstring M_VCMPEQSS;
+extern const fcml_cstring M_VCMPFALSE_OSPD;
+extern const fcml_cstring M_VCMPFALSE_OSPS;
 extern const fcml_cstring M_VCMPFALSE_OSSD;
 extern const fcml_cstring M_VCMPFALSE_OSSS;
+extern const fcml_cstring M_VCMPFALSEPD;
+extern const fcml_cstring M_VCMPFALSEPS;
 extern const fcml_cstring M_VCMPFALSESD;
 extern const fcml_cstring M_VCMPFALSESS;
+extern const fcml_cstring M_VCMPGE_OQPD;
+extern const fcml_cstring M_VCMPGE_OQPS;
 extern const fcml_cstring M_VCMPGE_OQSD;
 extern const fcml_cstring M_VCMPGE_OQSS;
+extern const fcml_cstring M_VCMPGEPD;
+extern const fcml_cstring M_VCMPGEPS;
 extern const fcml_cstring M_VCMPGESD;
 extern const fcml_cstring M_VCMPGESS;
+extern const fcml_cstring M_VCMPGT_OQPD;
+extern const fcml_cstring M_VCMPGT_OQPS;
 extern const fcml_cstring M_VCMPGT_OQSD;
 extern const fcml_cstring M_VCMPGT_OQSS;
+extern const fcml_cstring M_VCMPGTPD;
+extern const fcml_cstring M_VCMPGTPS;
 extern const fcml_cstring M_VCMPGTSD;
 extern const fcml_cstring M_VCMPGTSS;
+extern const fcml_cstring M_VCMPLE_OQPD;
+extern const fcml_cstring M_VCMPLE_OQPS;
 extern const fcml_cstring M_VCMPLE_OQSD;
 extern const fcml_cstring M_VCMPLE_OQSS;
+extern const fcml_cstring M_VCMPLEPD;
+extern const fcml_cstring M_VCMPLEPS;
 extern const fcml_cstring M_VCMPLESD;
 extern const fcml_cstring M_VCMPLESS;
+extern const fcml_cstring M_VCMPLT_OQPD;
+extern const fcml_cstring M_VCMPLT_OQPS;
 extern const fcml_cstring M_VCMPLT_OQSD;
 extern const fcml_cstring M_VCMPLT_OQSS;
+extern const fcml_cstring M_VCMPLTPD;
+extern const fcml_cstring M_VCMPLTPS;
 extern const fcml_cstring M_VCMPLTSD;
 extern const fcml_cstring M_VCMPLTSS;
+extern const fcml_cstring M_VCMPNEQ_OQPD;
+extern const fcml_cstring M_VCMPNEQ_OQPS;
 extern const fcml_cstring M_VCMPNEQ_OQSD;
 extern const fcml_cstring M_VCMPNEQ_OQSS;
+extern const fcml_cstring M_VCMPNEQ_OSPD;
+extern const fcml_cstring M_VCMPNEQ_OSPS;
 extern const fcml_cstring M_VCMPNEQ_OSSD;
 extern const fcml_cstring M_VCMPNEQ_OSSS;
-extern const fcml_cstring M_VCMPNEQSD;
-extern const fcml_cstring M_VCMPNEQSS;
+extern const fcml_cstring M_VCMPNEQ_USPD;
+extern const fcml_cstring M_VCMPNEQ_USPS;
 extern const fcml_cstring M_VCMPNEQ_USSD;
 extern const fcml_cstring M_VCMPNEQ_USSS;
-extern const fcml_cstring M_VCMPNGESD;
-extern const fcml_cstring M_VCMPNGESS;
+extern const fcml_cstring M_VCMPNEQPD;
+extern const fcml_cstring M_VCMPNEQPS;
+extern const fcml_cstring M_VCMPNEQSD;
+extern const fcml_cstring M_VCMPNEQSS;
+extern const fcml_cstring M_VCMPNGE_UQPD;
+extern const fcml_cstring M_VCMPNGE_UQPS;
 extern const fcml_cstring M_VCMPNGE_UQSD;
 extern const fcml_cstring M_VCMPNGE_UQSS;
-extern const fcml_cstring M_VCMPNGTSD;
-extern const fcml_cstring M_VCMPNGTSS;
+extern const fcml_cstring M_VCMPNGEPD;
+extern const fcml_cstring M_VCMPNGEPS;
+extern const fcml_cstring M_VCMPNGESD;
+extern const fcml_cstring M_VCMPNGESS;
+extern const fcml_cstring M_VCMPNGT_UQPD;
+extern const fcml_cstring M_VCMPNGT_UQPS;
 extern const fcml_cstring M_VCMPNGT_UQSD;
 extern const fcml_cstring M_VCMPNGT_UQSS;
-extern const fcml_cstring M_VCMPNLESD;
-extern const fcml_cstring M_VCMPNLESS;
+extern const fcml_cstring M_VCMPNGTPD;
+extern const fcml_cstring M_VCMPNGTPS;
+extern const fcml_cstring M_VCMPNGTSD;
+extern const fcml_cstring M_VCMPNGTSS;
+extern const fcml_cstring M_VCMPNLE_UQPD;
+extern const fcml_cstring M_VCMPNLE_UQPS;
 extern const fcml_cstring M_VCMPNLE_UQSD;
 extern const fcml_cstring M_VCMPNLE_UQSS;
-extern const fcml_cstring M_VCMPNLTSD;
-extern const fcml_cstring M_VCMPNLTSS;
+extern const fcml_cstring M_VCMPNLEPD;
+extern const fcml_cstring M_VCMPNLEPS;
+extern const fcml_cstring M_VCMPNLESD;
+extern const fcml_cstring M_VCMPNLESS;
+extern const fcml_cstring M_VCMPNLT_UQPD;
+extern const fcml_cstring M_VCMPNLT_UQPS;
 extern const fcml_cstring M_VCMPNLT_UQSD;
 extern const fcml_cstring M_VCMPNLT_UQSS;
-extern const fcml_cstring M_VCMPORDSD;
-extern const fcml_cstring M_VCMPORDSS;
+extern const fcml_cstring M_VCMPNLTPD;
+extern const fcml_cstring M_VCMPNLTPS;
+extern const fcml_cstring M_VCMPNLTSD;
+extern const fcml_cstring M_VCMPNLTSS;
+extern const fcml_cstring M_VCMPORD_SPD;
+extern const fcml_cstring M_VCMPORD_SPS;
 extern const fcml_cstring M_VCMPORD_SSD;
 extern const fcml_cstring M_VCMPORD_SSS;
+extern const fcml_cstring M_VCMPORDPD;
+extern const fcml_cstring M_VCMPORDPS;
+extern const fcml_cstring M_VCMPORDSD;
+extern const fcml_cstring M_VCMPORDSS;
 extern const fcml_cstring M_VCMPPD;
 extern const fcml_cstring M_VCMPPS;
 extern const fcml_cstring M_VCMPSD;
 extern const fcml_cstring M_VCMPSS;
-extern const fcml_cstring M_VCMPTRUESD;
-extern const fcml_cstring M_VCMPTRUESS;
+extern const fcml_cstring M_VCMPTRUE_USPD;
+extern const fcml_cstring M_VCMPTRUE_USPS;
 extern const fcml_cstring M_VCMPTRUE_USSD;
 extern const fcml_cstring M_VCMPTRUE_USSS;
-extern const fcml_cstring M_VCMPUNORDSD;
-extern const fcml_cstring M_VCMPUNORDSS;
+extern const fcml_cstring M_VCMPTRUEPD;
+extern const fcml_cstring M_VCMPTRUEPS;
+extern const fcml_cstring M_VCMPTRUESD;
+extern const fcml_cstring M_VCMPTRUESS;
+extern const fcml_cstring M_VCMPUNORD_SPD;
+extern const fcml_cstring M_VCMPUNORD_SPS;
 extern const fcml_cstring M_VCMPUNORD_SSD;
 extern const fcml_cstring M_VCMPUNORD_SSS;
+extern const fcml_cstring M_VCMPUNORDPD;
+extern const fcml_cstring M_VCMPUNORDPS;
+extern const fcml_cstring M_VCMPUNORDSD;
+extern const fcml_cstring M_VCMPUNORDSS;
 extern const fcml_cstring M_VCOMISD;
 extern const fcml_cstring M_VCOMISS;
+extern const fcml_cstring M_VCOMPRESSPD;
+extern const fcml_cstring M_VCOMPRESSPS;
 extern const fcml_cstring M_VCVTDQ2PD;
 extern const fcml_cstring M_VCVTDQ2PS;
 extern const fcml_cstring M_VCVTPD2DQ;
+extern const fcml_cstring M_VCVTPD2DQX;
+extern const fcml_cstring M_VCVTPD2DQY;
+extern const fcml_cstring M_VCVTPD2PS;
 extern const fcml_cstring M_VCVTPD2PSX;
 extern const fcml_cstring M_VCVTPD2PSY;
+extern const fcml_cstring M_VCVTPD2QQ;
+extern const fcml_cstring M_VCVTPD2UDQ;
+extern const fcml_cstring M_VCVTPD2UDQX;
+extern const fcml_cstring M_VCVTPD2UDQY;
+extern const fcml_cstring M_VCVTPD2UQQ;
 extern const fcml_cstring M_VCVTPH2PS;
 extern const fcml_cstring M_VCVTPS2DQ;
 extern const fcml_cstring M_VCVTPS2PD;
 extern const fcml_cstring M_VCVTPS2PH;
+extern const fcml_cstring M_VCVTPS2QQ;
+extern const fcml_cstring M_VCVTPS2UDQ;
+extern const fcml_cstring M_VCVTPS2UQQ;
+extern const fcml_cstring M_VCVTQQ2PD;
+extern const fcml_cstring M_VCVTQQ2PS;
+extern const fcml_cstring M_VCVTQQ2PSX;
+extern const fcml_cstring M_VCVTQQ2PSY;
 extern const fcml_cstring M_VCVTSD2SI;
 extern const fcml_cstring M_VCVTSD2SS;
+extern const fcml_cstring M_VCVTSD2USI;
 extern const fcml_cstring M_VCVTSI2SDL;
 extern const fcml_cstring M_VCVTSI2SDQ;
 extern const fcml_cstring M_VCVTSI2SSL;
 extern const fcml_cstring M_VCVTSI2SSQ;
 extern const fcml_cstring M_VCVTSS2SD;
 extern const fcml_cstring M_VCVTSS2SI;
+extern const fcml_cstring M_VCVTSS2USI;
+extern const fcml_cstring M_VCVTTPD2DQ;
 extern const fcml_cstring M_VCVTTPD2DQX;
 extern const fcml_cstring M_VCVTTPD2DQY;
+extern const fcml_cstring M_VCVTTPD2QQ;
+extern const fcml_cstring M_VCVTTPD2UDQ;
+extern const fcml_cstring M_VCVTTPD2UDQX;
+extern const fcml_cstring M_VCVTTPD2UDQY;
+extern const fcml_cstring M_VCVTTPD2UQQ;
 extern const fcml_cstring M_VCVTTPS2DQ;
+extern const fcml_cstring M_VCVTTPS2QQ;
+extern const fcml_cstring M_VCVTTPS2UDQ;
+extern const fcml_cstring M_VCVTTPS2UQQ;
 extern const fcml_cstring M_VCVTTSD2SI;
+extern const fcml_cstring M_VCVTTSD2USI;
 extern const fcml_cstring M_VCVTTSS2SI;
+extern const fcml_cstring M_VCVTTSS2USI;
+extern const fcml_cstring M_VCVTUDQ2PD;
+extern const fcml_cstring M_VCVTUDQ2PS;
+extern const fcml_cstring M_VCVTUQQ2PD;
+extern const fcml_cstring M_VCVTUQQ2PS;
+extern const fcml_cstring M_VCVTUQQ2PSX;
+extern const fcml_cstring M_VCVTUQQ2PSY;
+extern const fcml_cstring M_VCVTUSI2SD;
+extern const fcml_cstring M_VCVTUSI2SS;
+extern const fcml_cstring M_VDBPSADBW;
 extern const fcml_cstring M_VDIVPD;
 extern const fcml_cstring M_VDIVPS;
 extern const fcml_cstring M_VDIVSD;
@@ -1065,9 +1248,25 @@ extern const fcml_cstring M_VDPPD;
 extern const fcml_cstring M_VDPPS;
 extern const fcml_cstring M_VERR;
 extern const fcml_cstring M_VERW;
+extern const fcml_cstring M_VEXP2PD;
+extern const fcml_cstring M_VEXP2PS;
+extern const fcml_cstring M_VEXPANDPD;
+extern const fcml_cstring M_VEXPANDPS;
 extern const fcml_cstring M_VEXTRACTF128;
+extern const fcml_cstring M_VEXTRACTF32X4;
+extern const fcml_cstring M_VEXTRACTF32X8;
+extern const fcml_cstring M_VEXTRACTF64X2;
+extern const fcml_cstring M_VEXTRACTF64X4;
 extern const fcml_cstring M_VEXTRACTI128;
+extern const fcml_cstring M_VEXTRACTI32X4;
+extern const fcml_cstring M_VEXTRACTI32X8;
+extern const fcml_cstring M_VEXTRACTI64X2;
+extern const fcml_cstring M_VEXTRACTI64X4;
 extern const fcml_cstring M_VEXTRACTPS;
+extern const fcml_cstring M_VFIXUPIMMPD;
+extern const fcml_cstring M_VFIXUPIMMPS;
+extern const fcml_cstring M_VFIXUPIMMSD;
+extern const fcml_cstring M_VFIXUPIMMSS;
 extern const fcml_cstring M_VFMADD132PD;
 extern const fcml_cstring M_VFMADD132PS;
 extern const fcml_cstring M_VFMADD132SD;
@@ -1148,20 +1347,48 @@ extern const fcml_cstring M_VFNMSUBPD;
 extern const fcml_cstring M_VFNMSUBPS;
 extern const fcml_cstring M_VFNMSUBSD;
 extern const fcml_cstring M_VFNMSUBSS;
+extern const fcml_cstring M_VFPCLASSPD;
+extern const fcml_cstring M_VFPCLASSPS;
+extern const fcml_cstring M_VFPCLASSSD;
+extern const fcml_cstring M_VFPCLASSSS;
 extern const fcml_cstring M_VFRCZPD;
 extern const fcml_cstring M_VFRCZPS;
 extern const fcml_cstring M_VFRCZSD;
 extern const fcml_cstring M_VFRCZSS;
 extern const fcml_cstring M_VGATHERDPD;
 extern const fcml_cstring M_VGATHERDPS;
+extern const fcml_cstring M_VGATHERPF0DPD;
+extern const fcml_cstring M_VGATHERPF0DPS;
+extern const fcml_cstring M_VGATHERPF0QPD;
+extern const fcml_cstring M_VGATHERPF0QPS;
+extern const fcml_cstring M_VGATHERPF1DPD;
+extern const fcml_cstring M_VGATHERPF1DPS;
+extern const fcml_cstring M_VGATHERPF1QPD;
+extern const fcml_cstring M_VGATHERPF1QPS;
 extern const fcml_cstring M_VGATHERQPD;
 extern const fcml_cstring M_VGATHERQPS;
+extern const fcml_cstring M_VGETEXPPD;
+extern const fcml_cstring M_VGETEXPPS;
+extern const fcml_cstring M_VGETEXPSD;
+extern const fcml_cstring M_VGETEXPSS;
+extern const fcml_cstring M_VGETMANTPD;
+extern const fcml_cstring M_VGETMANTPS;
+extern const fcml_cstring M_VGETMANTSD;
+extern const fcml_cstring M_VGETMANTSS;
 extern const fcml_cstring M_VHADDPD;
 extern const fcml_cstring M_VHADDPS;
 extern const fcml_cstring M_VHSUBPD;
 extern const fcml_cstring M_VHSUBPS;
 extern const fcml_cstring M_VINSERTF128;
+extern const fcml_cstring M_VINSERTF32X4;
+extern const fcml_cstring M_VINSERTF32X8;
+extern const fcml_cstring M_VINSERTF64X2;
+extern const fcml_cstring M_VINSERTF64X4;
 extern const fcml_cstring M_VINSERTI128;
+extern const fcml_cstring M_VINSERTI32X4;
+extern const fcml_cstring M_VINSERTI32X8;
+extern const fcml_cstring M_VINSERTI64X2;
+extern const fcml_cstring M_VINSERTI64X4;
 extern const fcml_cstring M_VINSERTPS;
 extern const fcml_cstring M_VLDDQU;
 extern const fcml_cstring M_VLDMXCSR;
@@ -1187,7 +1414,13 @@ extern const fcml_cstring M_VMOVAPS;
 extern const fcml_cstring M_VMOVD;
 extern const fcml_cstring M_VMOVDDUP;
 extern const fcml_cstring M_VMOVDQA;
+extern const fcml_cstring M_VMOVDQA32;
+extern const fcml_cstring M_VMOVDQA64;
 extern const fcml_cstring M_VMOVDQU;
+extern const fcml_cstring M_VMOVDQU16;
+extern const fcml_cstring M_VMOVDQU32;
+extern const fcml_cstring M_VMOVDQU64;
+extern const fcml_cstring M_VMOVDQU8;
 extern const fcml_cstring M_VMOVHLPS;
 extern const fcml_cstring M_VMOVHPD;
 extern const fcml_cstring M_VMOVHPS;
@@ -1223,8 +1456,11 @@ extern const fcml_cstring M_VMXOFF;
 extern const fcml_cstring M_VMXON;
 extern const fcml_cstring M_VORPD;
 extern const fcml_cstring M_VORPS;
+extern const fcml_cstring M_VP4DPWSSD;
+extern const fcml_cstring M_VP4DPWSSDS;
 extern const fcml_cstring M_VPABSB;
 extern const fcml_cstring M_VPABSD;
+extern const fcml_cstring M_VPABSQ;
 extern const fcml_cstring M_VPABSW;
 extern const fcml_cstring M_VPACKSSDW;
 extern const fcml_cstring M_VPACKSSWB;
@@ -1240,18 +1476,30 @@ extern const fcml_cstring M_VPADDUSW;
 extern const fcml_cstring M_VPADDW;
 extern const fcml_cstring M_VPALIGNR;
 extern const fcml_cstring M_VPAND;
+extern const fcml_cstring M_VPANDD;
 extern const fcml_cstring M_VPANDN;
+extern const fcml_cstring M_VPANDND;
+extern const fcml_cstring M_VPANDNQ;
+extern const fcml_cstring M_VPANDQ;
 extern const fcml_cstring M_VPAVGB;
 extern const fcml_cstring M_VPAVGW;
 extern const fcml_cstring M_VPBLENDD;
+extern const fcml_cstring M_VPBLENDMB;
+extern const fcml_cstring M_VPBLENDMD;
+extern const fcml_cstring M_VPBLENDMQ;
+extern const fcml_cstring M_VPBLENDMW;
 extern const fcml_cstring M_VPBLENDVB;
 extern const fcml_cstring M_VPBLENDW;
 extern const fcml_cstring M_VPBROADCASTB;
 extern const fcml_cstring M_VPBROADCASTD;
+extern const fcml_cstring M_VPBROADCASTMB2Q;
+extern const fcml_cstring M_VPBROADCASTMW2D;
 extern const fcml_cstring M_VPBROADCASTQ;
 extern const fcml_cstring M_VPBROADCASTW;
 extern const fcml_cstring M_VPCLMULQDQ;
 extern const fcml_cstring M_VPCMOV;
+extern const fcml_cstring M_VPCMPB;
+extern const fcml_cstring M_VPCMPD;
 extern const fcml_cstring M_VPCMPEQB;
 extern const fcml_cstring M_VPCMPEQD;
 extern const fcml_cstring M_VPCMPEQQ;
@@ -1264,6 +1512,12 @@ extern const fcml_cstring M_VPCMPGTQ;
 extern const fcml_cstring M_VPCMPGTW;
 extern const fcml_cstring M_VPCMPISTRI;
 extern const fcml_cstring M_VPCMPISTRM;
+extern const fcml_cstring M_VPCMPQ;
+extern const fcml_cstring M_VPCMPUB;
+extern const fcml_cstring M_VPCMPUD;
+extern const fcml_cstring M_VPCMPUQ;
+extern const fcml_cstring M_VPCMPUW;
+extern const fcml_cstring M_VPCMPW;
 extern const fcml_cstring M_VPCOMB;
 extern const fcml_cstring M_VPCOMD;
 extern const fcml_cstring M_VPCOMEQB;
@@ -1322,6 +1576,8 @@ extern const fcml_cstring M_VPCOMNEQUD;
 extern const fcml_cstring M_VPCOMNEQUQ;
 extern const fcml_cstring M_VPCOMNEQUW;
 extern const fcml_cstring M_VPCOMNEQW;
+extern const fcml_cstring M_VPCOMPRESSD;
+extern const fcml_cstring M_VPCOMPRESSQ;
 extern const fcml_cstring M_VPCOMQ;
 extern const fcml_cstring M_VPCOMTRUEB;
 extern const fcml_cstring M_VPCOMTRUED;
@@ -1338,7 +1594,14 @@ extern const fcml_cstring M_VPCOMUW;
 extern const fcml_cstring M_VPCOMW;
 extern const fcml_cstring M_VPERM2F128;
 extern const fcml_cstring M_VPERM2I128;
+extern const fcml_cstring M_VPERMB;
 extern const fcml_cstring M_VPERMD;
+extern const fcml_cstring M_VPERMI2B;
+extern const fcml_cstring M_VPERMI2D;
+extern const fcml_cstring M_VPERMI2PD;
+extern const fcml_cstring M_VPERMI2PS;
+extern const fcml_cstring M_VPERMI2Q;
+extern const fcml_cstring M_VPERMI2W;
 extern const fcml_cstring M_VPERMIL2PD;
 extern const fcml_cstring M_VPERMIL2PS;
 extern const fcml_cstring M_VPERMILPD;
@@ -1346,6 +1609,15 @@ extern const fcml_cstring M_VPERMILPS;
 extern const fcml_cstring M_VPERMPD;
 extern const fcml_cstring M_VPERMPS;
 extern const fcml_cstring M_VPERMQ;
+extern const fcml_cstring M_VPERMT2B;
+extern const fcml_cstring M_VPERMT2D;
+extern const fcml_cstring M_VPERMT2PD;
+extern const fcml_cstring M_VPERMT2PS;
+extern const fcml_cstring M_VPERMT2Q;
+extern const fcml_cstring M_VPERMT2W;
+extern const fcml_cstring M_VPERMW;
+extern const fcml_cstring M_VPEXPANDD;
+extern const fcml_cstring M_VPEXPANDQ;
 extern const fcml_cstring M_VPEXTRB;
 extern const fcml_cstring M_VPEXTRD;
 extern const fcml_cstring M_VPEXTRQ;
@@ -1380,6 +1652,8 @@ extern const fcml_cstring M_VPINSRB;
 extern const fcml_cstring M_VPINSRD;
 extern const fcml_cstring M_VPINSRQ;
 extern const fcml_cstring M_VPINSRW;
+extern const fcml_cstring M_VPLZCNTD;
+extern const fcml_cstring M_VPLZCNTQ;
 extern const fcml_cstring M_VPMACSDD;
 extern const fcml_cstring M_VPMACSDQH;
 extern const fcml_cstring M_VPMACSDQL;
@@ -1392,6 +1666,8 @@ extern const fcml_cstring M_VPMACSWD;
 extern const fcml_cstring M_VPMACSWW;
 extern const fcml_cstring M_VPMADCSSWD;
 extern const fcml_cstring M_VPMADCSWD;
+extern const fcml_cstring M_VPMADD52HUQ;
+extern const fcml_cstring M_VPMADD52LUQ;
 extern const fcml_cstring M_VPMADDUBSW;
 extern const fcml_cstring M_VPMADDWD;
 extern const fcml_cstring M_VPMASKMOV;
@@ -1399,23 +1675,53 @@ extern const fcml_cstring M_VPMASKMOVD;
 extern const fcml_cstring M_VPMASKMOVQ;
 extern const fcml_cstring M_VPMAXSB;
 extern const fcml_cstring M_VPMAXSD;
+extern const fcml_cstring M_VPMAXSQ;
 extern const fcml_cstring M_VPMAXSW;
 extern const fcml_cstring M_VPMAXUB;
 extern const fcml_cstring M_VPMAXUD;
+extern const fcml_cstring M_VPMAXUQ;
 extern const fcml_cstring M_VPMAXUW;
 extern const fcml_cstring M_VPMINSB;
 extern const fcml_cstring M_VPMINSD;
+extern const fcml_cstring M_VPMINSQ;
 extern const fcml_cstring M_VPMINSW;
 extern const fcml_cstring M_VPMINUB;
 extern const fcml_cstring M_VPMINUD;
+extern const fcml_cstring M_VPMINUQ;
 extern const fcml_cstring M_VPMINUW;
+extern const fcml_cstring M_VPMOVB2M;
+extern const fcml_cstring M_VPMOVD2M;
+extern const fcml_cstring M_VPMOVDB;
+extern const fcml_cstring M_VPMOVDW;
+extern const fcml_cstring M_VPMOVM2B;
+extern const fcml_cstring M_VPMOVM2D;
+extern const fcml_cstring M_VPMOVM2Q;
+extern const fcml_cstring M_VPMOVM2W;
 extern const fcml_cstring M_VPMOVMSKB;
+extern const fcml_cstring M_VPMOVQ2M;
+extern const fcml_cstring M_VPMOVQB;
+extern const fcml_cstring M_VPMOVQD;
+extern const fcml_cstring M_VPMOVQW;
+extern const fcml_cstring M_VPMOVSDB;
+extern const fcml_cstring M_VPMOVSDW;
+extern const fcml_cstring M_VPMOVSQB;
+extern const fcml_cstring M_VPMOVSQD;
+extern const fcml_cstring M_VPMOVSQW;
+extern const fcml_cstring M_VPMOVSWB;
 extern const fcml_cstring M_VPMOVSXBD;
 extern const fcml_cstring M_VPMOVSXBQ;
 extern const fcml_cstring M_VPMOVSXBW;
 extern const fcml_cstring M_VPMOVSXDQ;
 extern const fcml_cstring M_VPMOVSXWD;
 extern const fcml_cstring M_VPMOVSXWQ;
+extern const fcml_cstring M_VPMOVUSDB;
+extern const fcml_cstring M_VPMOVUSDW;
+extern const fcml_cstring M_VPMOVUSQB;
+extern const fcml_cstring M_VPMOVUSQD;
+extern const fcml_cstring M_VPMOVUSQW;
+extern const fcml_cstring M_VPMOVUSWB;
+extern const fcml_cstring M_VPMOVW2M;
+extern const fcml_cstring M_VPMOVWB;
 extern const fcml_cstring M_VPMOVZXBD;
 extern const fcml_cstring M_VPMOVZXBQ;
 extern const fcml_cstring M_VPMOVZXBW;
@@ -1427,15 +1733,31 @@ extern const fcml_cstring M_VPMULHRSW;
 extern const fcml_cstring M_VPMULHUW;
 extern const fcml_cstring M_VPMULHW;
 extern const fcml_cstring M_VPMULLD;
+extern const fcml_cstring M_VPMULLQ;
 extern const fcml_cstring M_VPMULLW;
+extern const fcml_cstring M_VPMULTISHIFTQB;
 extern const fcml_cstring M_VPMULUDQ;
 extern const fcml_cstring M_VPOR;
+extern const fcml_cstring M_VPORD;
+extern const fcml_cstring M_VPORQ;
 extern const fcml_cstring M_VPPERM;
+extern const fcml_cstring M_VPROLD;
+extern const fcml_cstring M_VPROLQ;
+extern const fcml_cstring M_VPROLVD;
+extern const fcml_cstring M_VPROLVQ;
+extern const fcml_cstring M_VPRORD;
+extern const fcml_cstring M_VPRORQ;
+extern const fcml_cstring M_VPRORVD;
+extern const fcml_cstring M_VPRORVQ;
 extern const fcml_cstring M_VPROTB;
 extern const fcml_cstring M_VPROTD;
 extern const fcml_cstring M_VPROTQ;
 extern const fcml_cstring M_VPROTW;
 extern const fcml_cstring M_VPSADBW;
+extern const fcml_cstring M_VPSCATTERDD;
+extern const fcml_cstring M_VPSCATTERDQ;
+extern const fcml_cstring M_VPSCATTERQD;
+extern const fcml_cstring M_VPSCATTERQQ;
 extern const fcml_cstring M_VPSHAB;
 extern const fcml_cstring M_VPSHAD;
 extern const fcml_cstring M_VPSHAQ;
@@ -1456,15 +1778,20 @@ extern const fcml_cstring M_VPSLLDQ;
 extern const fcml_cstring M_VPSLLQ;
 extern const fcml_cstring M_VPSLLVD;
 extern const fcml_cstring M_VPSLLVQ;
+extern const fcml_cstring M_VPSLLVW;
 extern const fcml_cstring M_VPSLLW;
 extern const fcml_cstring M_VPSRAD;
+extern const fcml_cstring M_VPSRAQ;
 extern const fcml_cstring M_VPSRAVD;
+extern const fcml_cstring M_VPSRAVQ;
+extern const fcml_cstring M_VPSRAVW;
 extern const fcml_cstring M_VPSRAW;
 extern const fcml_cstring M_VPSRLD;
 extern const fcml_cstring M_VPSRLDQ;
 extern const fcml_cstring M_VPSRLQ;
 extern const fcml_cstring M_VPSRLVD;
 extern const fcml_cstring M_VPSRLVQ;
+extern const fcml_cstring M_VPSRLVW;
 extern const fcml_cstring M_VPSRLW;
 extern const fcml_cstring M_VPSUBB;
 extern const fcml_cstring M_VPSUBD;
@@ -1474,7 +1801,17 @@ extern const fcml_cstring M_VPSUBSW;
 extern const fcml_cstring M_VPSUBUSB;
 extern const fcml_cstring M_VPSUBUSW;
 extern const fcml_cstring M_VPSUBW;
+extern const fcml_cstring M_VPTERNLOGD;
+extern const fcml_cstring M_VPTERNLOGQ;
 extern const fcml_cstring M_VPTEST;
+extern const fcml_cstring M_VPTESTMB;
+extern const fcml_cstring M_VPTESTMD;
+extern const fcml_cstring M_VPTESTMQ;
+extern const fcml_cstring M_VPTESTMW;
+extern const fcml_cstring M_VPTESTNMB;
+extern const fcml_cstring M_VPTESTNMD;
+extern const fcml_cstring M_VPTESTNMQ;
+extern const fcml_cstring M_VPTESTNMW;
 extern const fcml_cstring M_VPUNPCKHBW;
 extern const fcml_cstring M_VPUNPCKHDQ;
 extern const fcml_cstring M_VPUNPCKHQDQ;
@@ -1484,14 +1821,64 @@ extern const fcml_cstring M_VPUNPCKLDQ;
 extern const fcml_cstring M_VPUNPCKLQDQ;
 extern const fcml_cstring M_VPUNPCKLWD;
 extern const fcml_cstring M_VPXOR;
+extern const fcml_cstring M_VPXORD;
+extern const fcml_cstring M_VPXORQ;
+extern const fcml_cstring M_VRANGEPD;
+extern const fcml_cstring M_VRANGEPS;
+extern const fcml_cstring M_VRANGESD;
+extern const fcml_cstring M_VRANGESS;
+extern const fcml_cstring M_VRCP14PD;
+extern const fcml_cstring M_VRCP14PS;
+extern const fcml_cstring M_VRCP14SD;
+extern const fcml_cstring M_VRCP14SS;
+extern const fcml_cstring M_VRCP28PD;
+extern const fcml_cstring M_VRCP28PS;
+extern const fcml_cstring M_VRCP28SD;
+extern const fcml_cstring M_VRCP28SS;
 extern const fcml_cstring M_VRCPPS;
 extern const fcml_cstring M_VRCPSS;
+extern const fcml_cstring M_VREDUCEPD;
+extern const fcml_cstring M_VREDUCEPS;
+extern const fcml_cstring M_VREDUCESD;
+extern const fcml_cstring M_VREDUCESS;
+extern const fcml_cstring M_VRNDSCALEPD;
+extern const fcml_cstring M_VRNDSCALEPS;
+extern const fcml_cstring M_VRNDSCALESD;
+extern const fcml_cstring M_VRNDSCALESS;
 extern const fcml_cstring M_VROUNDPD;
 extern const fcml_cstring M_VROUNDPS;
 extern const fcml_cstring M_VROUNDSD;
 extern const fcml_cstring M_VROUNDSS;
+extern const fcml_cstring M_VRSQRT14PD;
+extern const fcml_cstring M_VRSQRT14PS;
+extern const fcml_cstring M_VRSQRT14SD;
+extern const fcml_cstring M_VRSQRT14SS;
+extern const fcml_cstring M_VRSQRT28PD;
+extern const fcml_cstring M_VRSQRT28PS;
+extern const fcml_cstring M_VRSQRT28SD;
+extern const fcml_cstring M_VRSQRT28SS;
 extern const fcml_cstring M_VRSQRTPS;
 extern const fcml_cstring M_VRSQRTSS;
+extern const fcml_cstring M_VSCALEFPD;
+extern const fcml_cstring M_VSCALEFPS;
+extern const fcml_cstring M_VSCALEFSD;
+extern const fcml_cstring M_VSCALEFSS;
+extern const fcml_cstring M_VSCATTERDPD;
+extern const fcml_cstring M_VSCATTERDPS;
+extern const fcml_cstring M_VSCATTERPF0DPD;
+extern const fcml_cstring M_VSCATTERPF0DPS;
+extern const fcml_cstring M_VSCATTERPF0QPD;
+extern const fcml_cstring M_VSCATTERPF0QPS;
+extern const fcml_cstring M_VSCATTERPF1DPD;
+extern const fcml_cstring M_VSCATTERPF1DPS;
+extern const fcml_cstring M_VSCATTERPF1QPD;
+extern const fcml_cstring M_VSCATTERPF1QPS;
+extern const fcml_cstring M_VSCATTERQPD;
+extern const fcml_cstring M_VSCATTERQPS;
+extern const fcml_cstring M_VSHUFF32X4;
+extern const fcml_cstring M_VSHUFF64X2;
+extern const fcml_cstring M_VSHUFI32X4;
+extern const fcml_cstring M_VSHUFI64X2;
 extern const fcml_cstring M_VSHUFPD;
 extern const fcml_cstring M_VSHUFPS;
 extern const fcml_cstring M_VSQRTPD;
