@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2019 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 
 /** @file fcml_instructions.h
  * Instruction codes and addressing modes/instruction forms.
- * @copyright Copyright (C) 2010-2015 Slawomir Wojtasiak. All rights reserved.
+ * @copyright Copyright (C) 2010-2017 Slawomir Wojtasiak. All rights reserved.
  * This project is released under the GNU Lesser General Public License.
  */
 
@@ -78,23 +78,26 @@
 /* Control transfer instructions. */
 #define    FCML_AMT_CTI        0x0000010000000000UL
 #define    FCML_AMT_BRANCH     0x0000020000000000UL
+/* End of control transfer instructions. */
+#define    FCML_AMT_AVX512     0x0000040000000000UL
 /* Shortcuts. */
-#define    FCML_AMT_MMX_SIMD   FCML_AMT_MMX   | FCML_AMT_SIMD
-#define    FCML_AMT_SSE_SIMD   FCML_AMT_SSE   | FCML_AMT_SIMD
-#define    FCML_AMT_SSE2_SIMD  FCML_AMT_SSE2  | FCML_AMT_SIMD
-#define    FCML_AMT_SSE3_SIMD  FCML_AMT_SSE3  | FCML_AMT_SIMD
-#define    FCML_AMT_SSSE3_SIMD FCML_AMT_SSSE3 | FCML_AMT_SIMD
-#define    FCML_AMT_SSE41_SIMD FCML_AMT_SSE41 | FCML_AMT_SIMD
-#define    FCML_AMT_SSE42_SIMD FCML_AMT_SSE42 | FCML_AMT_SIMD
-#define    FCML_AMT_AVX_SIMD   FCML_AMT_AVX   | FCML_AMT_SIMD
-#define    FCML_AMT_AVX2_SIMD  FCML_AMT_AVX2  | FCML_AMT_SIMD
-#define    FCML_AMT_3DNOW_SIMD FCML_AMT_3DNOW | FCML_AMT_SIMD
+#define    FCML_AMT_MMX_SIMD    FCML_AMT_MMX    | FCML_AMT_SIMD
+#define    FCML_AMT_SSE_SIMD    FCML_AMT_SSE    | FCML_AMT_SIMD
+#define    FCML_AMT_SSE2_SIMD   FCML_AMT_SSE2   | FCML_AMT_SIMD
+#define    FCML_AMT_SSE3_SIMD   FCML_AMT_SSE3   | FCML_AMT_SIMD
+#define    FCML_AMT_SSSE3_SIMD  FCML_AMT_SSSE3  | FCML_AMT_SIMD
+#define    FCML_AMT_SSE41_SIMD  FCML_AMT_SSE41  | FCML_AMT_SIMD
+#define    FCML_AMT_SSE42_SIMD  FCML_AMT_SSE42  | FCML_AMT_SIMD
+#define    FCML_AMT_AVX_SIMD    FCML_AMT_AVX    | FCML_AMT_SIMD
+#define    FCML_AMT_AVX2_SIMD   FCML_AMT_AVX2   | FCML_AMT_SIMD
+#define    FCML_AMT_3DNOW_SIMD  FCML_AMT_3DNOW  | FCML_AMT_SIMD
+#define    FCML_AMT_AVX512_SIMD FCML_AMT_AVX512 | FCML_AMT_SIMD
 
 /** @} */
 
 /** Instruction forms. */
 enum fcml_en_instruction_addr_mode_codes {
-    FCML_AM_UNKNOWN = 0,
+    FCML_AM_UNKNOWN,
     FCML_AM_NO_OPERANS,
     FCML_AM_IMM8,
     FCML_AM_IMMO,
@@ -461,7 +464,19 @@ typedef enum fcml_en_instruction {
     F_INSERTPS,
     F_VINSERTPS,
     F_VEXTRACTF128,
+    F_VEXTRACTF32X4,
+    F_VEXTRACTF64X2,
+    F_VEXTRACTF32X8,
+    F_VEXTRACTF64X4,
+    F_VEXTRACTI32X4,
+    F_VEXTRACTI64X2,
+    F_VEXTRACTI32X8,
+    F_VEXTRACTI64X4,
     F_VINSERTF128,
+    F_VFIXUPIMMPD,
+    F_VFIXUPIMMPS,
+    F_VFIXUPIMMSD,
+    F_VFIXUPIMMSS,
     F_INSERTQ,
     F_INT3,
     F_INT,
@@ -475,6 +490,54 @@ typedef enum fcml_en_instruction {
     F_JECXZ = F_JCXZ,
     F_JRCXZ = F_JCXZ,
     F_JMP,
+    F_KADDB,
+    F_KADDD,
+    F_KADDW,
+    F_KADDQ,
+    F_KANDB,
+    F_KANDD,
+    F_KANDW,
+    F_KANDQ,
+    F_KANDNB,
+    F_KANDND,
+    F_KANDNW,
+    F_KANDNQ,
+    F_KMOVB,
+    F_KMOVW,
+    F_KMOVD,
+    F_KMOVQ,
+    F_KNOTB,
+    F_KNOTW,
+    F_KNOTD,
+    F_KNOTQ,
+    F_KORB,
+    F_KORW,
+    F_KORD,
+    F_KORQ,
+    F_KORTESTB,
+    F_KORTESTW,
+    F_KORTESTD,
+    F_KORTESTQ,
+    F_KSHIFTLW,
+    F_KSHIFTLB,
+    F_KSHIFTLQ,
+    F_KSHIFTLD,
+    F_KSHIFTRW,
+    F_KSHIFTRB,
+    F_KSHIFTRQ,
+    F_KSHIFTRD,
+    F_KTESTB,
+    F_KTESTW,
+    F_KTESTD,
+    F_KTESTQ,
+    F_KXNORB,
+    F_KXNORD,
+    F_KXNORW,
+    F_KXNORQ,
+    F_KXORB,
+    F_KXORD,
+    F_KXORW,
+    F_KXORQ,
     F_LAR,
     F_LAHF,
     F_LDDQU,
@@ -543,8 +606,14 @@ typedef enum fcml_en_instruction {
     F_VMOVDDUP,
     F_MOVDQA,
     F_VMOVDQA,
+    F_VMOVDQA32,
+    F_VMOVDQA64,
     F_MOVDQU,
     F_VMOVDQU,
+    F_VMOVDQU8,
+    F_VMOVDQU16,
+    F_VMOVDQU32,
+    F_VMOVDQU64,
     F_MOVDQ2Q,
     F_MOVHLPS,
     F_VMOVHLPS,
@@ -619,6 +688,7 @@ typedef enum fcml_en_instruction {
     F_VPABSB,
     F_VPABSW,
     F_VPABSD,
+    F_VPABSQ,
     F_VPACKSSWB,
     F_PACKSSWB,
     F_VPACKSSDW,
@@ -683,8 +753,12 @@ typedef enum fcml_en_instruction {
     F_VPALIGNR,
     F_PAND,
     F_VPAND,
+    F_VPANDD,
+    F_VPANDQ,
     F_PANDN,
     F_VPANDN,
+    F_VPANDND,
+    F_VPANDNQ,
     F_PAUSE,
     F_PAVGW,
     F_PAVGB,
@@ -759,18 +833,21 @@ typedef enum fcml_en_instruction {
     F_VPMAXSB,
     F_PMAXSD,
     F_VPMAXSD,
+    F_VPMAXSQ,
     F_PMAXSW,
     F_VPMAXSW,
     F_PMAXUB,
     F_VPMAXUB,
     F_PMAXUD,
     F_VPMAXUD,
+    F_VPMAXUQ,
     F_PMAXUW,
     F_VPMAXUW,
     F_PMINSB,
     F_VPMINSB,
     F_PMINSD,
     F_VPMINSD,
+    F_VPMINSQ,
     F_PMINSW,
     F_VPMINSW,
     F_PMINUW,
@@ -779,6 +856,7 @@ typedef enum fcml_en_instruction {
     F_VPMINUB,
     F_PMINUD,
     F_VPMINUD,
+    F_VPMINUQ,
     F_PMOVMSKB,
     F_VPMOVMSKB,
     F_VPMOVSXBQ,
@@ -818,15 +896,19 @@ typedef enum fcml_en_instruction {
     F_PMULLW,
     F_PMULLD,
     F_VPMULLD,
+    F_VPMULLQ,
     F_VPMULLW,
     F_POPCNT,
     F_POR,
     F_VPOR,
+    F_VPORD,
+    F_VPORQ,
     F_PREFETCHT2,
     F_PREFETCHW,
     F_PREFETCHT1,
     F_PREFETCHNTA,
     F_PREFETCHT0,
+    F_PREFETCHWT1,
     F_PSADBW,
     F_VPSADBW,
     F_PSHUFB,
@@ -856,6 +938,7 @@ typedef enum fcml_en_instruction {
     F_PSRAD,
     F_PSRAW,
     F_VPSRAD,
+    F_VPSRAQ,
     F_PSRLDQ,
     F_VPSRLDQ,
     F_VPSRLQ,
@@ -900,6 +983,8 @@ typedef enum fcml_en_instruction {
     F_VPUNPCKHDQ,
     F_PXOR,
     F_VPXOR,
+    F_VPXORD,
+    F_VPXORQ,
     F_PREFETCH,
     F_RCL,
     F_RCR,
@@ -1127,12 +1212,42 @@ typedef enum fcml_en_instruction {
     F_VFNMSUB132SS,
     F_VFNMSUB213SS,
     F_VFNMSUB231SS,
+    F_VFPCLASSPD,
+    F_VFPCLASSPS,
+    F_VFPCLASSSD,
+    F_VFPCLASSSS,
     F_BEXTR,
     F_VPBROADCASTW,
     F_VPBROADCASTB,
     F_VPBROADCASTD,
     F_VPBROADCASTQ,
+    F_VBROADCASTI32X2,
+    F_VBROADCASTI32X4,
+    F_VBROADCASTI64X2,
+    F_VBROADCASTI32X8,
+    F_VBROADCASTI64X4,
+    F_VPBROADCASTMB2Q,
+    F_VPBROADCASTMW2D,
+    F_VPCMPB,
+    F_VPCMPUB,
+    F_VPCMPW,
+    F_VPCMPUW,
+    F_VPCMPD,
+    F_VPCMPUD,
+    F_VPCMPQ,
+    F_VPCMPUQ,
+    F_VCOMPRESSPD,
+    F_VCOMPRESSPS,
+    F_VPCOMPRESSD,
+    F_VPCOMPRESSQ,
+    F_VCVTPD2QQ,
+    F_VCVTTPS2UQQ,
+    F_VCVTTPS2QQ,
+    F_VCVTPD2UDQ,
+    F_VCVTTPD2UQQ,
+    F_VCVTTPS2UDQ,
     F_VMPTRLD,
+    F_VCVTPD2UQQ,
     F_VMPTRST,
     F_VMCLEAR,
     F_VMREAD,
@@ -1143,27 +1258,161 @@ typedef enum fcml_en_instruction {
     F_VMXON,
     F_VMCALL,
     F_VMFUNC,
+    F_VALIGND,
+    F_VALIGNQ,
+    F_VBLENDMPD,
+    F_VBLENDMPS,
     F_VBROADCASTSD,
     F_VBROADCASTSS,
     F_VBROADCASTI128,
     F_VBROADCASTF128,
+    F_VBROADCASTF32X2,
+    F_VBROADCASTF32X4,
+    F_VBROADCASTF32X8,
+    F_VBROADCASTF64X2,
+    F_VBROADCASTF64X4,
     F_VCVTPH2PS,
     F_VCVTPS2PH,
+    F_VCVTPS2QQ,
+    F_VCVTPS2UDQ,
+    F_VCVTPS2UQQ,
+    F_VCVTQQ2PD,
+    F_VCVTQQ2PS,
+    F_VCVTSD2USI,
+    F_VCVTSS2USI,
+    F_VCVTTSD2USI,
+    F_VCVTTSS2USI,
+    F_VCVTTPD2QQ,
+    F_VCVTUDQ2PS,
+    F_VCVTUQQ2PD,
+    F_VCVTUSI2SD,
+    F_VCVTUSI2SS,
+    F_VCVTUQQ2PS,
+    F_VCVTUDQ2PD,
+    F_VCVTTPD2UDQ,
+    F_VDBPSADBW,
+    F_VEXPANDPD,
+    F_VEXPANDPS,
     F_VERR,
     F_VERW,
     F_VMMCALL,
     F_VPERMILPD,
     F_VPERMILPS,
-    F_VPSLLVQ,
     F_VPERM2F128,
     F_VPERM2I128,
+    F_VPERMI2W,
+    F_VPERMI2D,
+    F_VPERMI2Q,
+    F_VPERMI2PS,
+    F_VPERMI2PD,
+    F_VPERMT2B,
+    F_VPERMT2W,
+    F_VPERMT2D,
+    F_VPERMT2Q,
+    F_VPERMT2PS,
+    F_VPERMT2PD,
+    F_VPEXPANDD,
+    F_VPEXPANDQ,
+    F_VPLZCNTD,
+    F_VPLZCNTQ,
+    F_VPMOVB2M,
+    F_VPMOVW2M,
+    F_VPMOVD2M,
+    F_VPMOVQ2M,
+    F_VPMOVM2B,
+    F_VPMOVM2W,
+    F_VPMOVM2D,
+    F_VPMOVM2Q,
+    F_VPMOVDB,
+    F_VPMOVSDB,
+    F_VPMOVUSDB,
+    F_VPMOVDW,
+    F_VPMOVSDW,
+    F_VPMOVUSDW,
+    F_VPMOVQB,
+    F_VPMOVSQB,
+    F_VPMOVUSQB,
+    F_VPMOVQD,
+    F_VPMOVSQD,
+    F_VPMOVUSQD,
+    F_VPMOVQW,
+    F_VPMOVSQW,
+    F_VPMOVUSQW,
+    F_VPMOVWB,
+    F_VPMOVSWB,
+    F_VPMOVUSWB,
+    F_VPMULTISHIFTQB,
+    F_VPROLVD,
+    F_VPROLVQ,
+    F_VPROLD,
+    F_VPROLQ,
+    F_VPRORVD,
+    F_VPRORVQ,
+    F_VPRORD,
+    F_VPRORQ,
+    F_VPSCATTERDD,
+    F_VPSCATTERDQ,
+    F_VPSCATTERQD,
+    F_VPSCATTERQQ,
+    F_VPSLLVW,
+    F_VPSLLVD,
+    F_VPSLLVQ,
+    F_VPMADD52HUQ,
+    F_VPMADD52LUQ,
     F_VEXTRACTI128,
     F_VINSERTI128,
+    F_VPSRAVW,
     F_VPSRAVD,
+    F_VPSRAVQ,
     F_VPERMD,
-    F_VPSLLVD,
+    F_VPERMW,
+    F_VPERMI2B,
+    F_VPERMB,
+    F_VPSRLVW,
     F_VPSRLVD,
     F_VPSRLVQ,
+    F_VPTERNLOGD,
+    F_VPTERNLOGQ,
+    F_VPTESTMB,
+    F_VPTESTMW,
+    F_VPTESTMD,
+    F_VPTESTMQ,
+    F_VPTESTNMB,
+    F_VPTESTNMW,
+    F_VPTESTNMD,
+    F_VPTESTNMQ,
+    F_VRANGEPD,
+    F_VRANGEPS,
+    F_VRANGESD,
+    F_VRANGESS,
+    F_VRCP14PD,
+    F_VRCP14PS,
+    F_VRCP14SD,
+    F_VRCP14SS,
+    F_VREDUCEPD,
+    F_VREDUCEPS,
+    F_VREDUCESD,
+    F_VREDUCESS,
+    F_VRNDSCALEPD,
+    F_VRNDSCALEPS,
+    F_VRNDSCALESD,
+    F_VRNDSCALESS,
+    F_VRSQRT14PD,
+    F_VRSQRT14PS,
+    F_VRSQRT14SD,
+    F_VRSQRT14SS,
+    F_VSCALEFPD,
+    F_VSCALEFPS,
+    F_VSCALEFSD,
+    F_VSCALEFSS,
+    F_VSCATTERDPS,
+    F_VSCATTERDPD,
+    F_VSCATTERQPS,
+    F_VSCATTERQPD,
+    F_VSHUFF32X4,
+    F_VSHUFF64X2,
+    F_VSHUFI32X4,
+    F_VSHUFI64X2,
     F_VPERMPD,
     F_VPERMQ,
     F_VPERMPS,
@@ -1177,6 +1426,26 @@ typedef enum fcml_en_instruction {
     F_VPGATHERQD,
     F_VPGATHERDQ,
     F_VPGATHERQQ,
+    F_VGETEXPPD,
+    F_VGETEXPPS,
+    F_VGETEXPSD,
+    F_VGETEXPSS,
+    F_VGETMANTPD,
+    F_VGETMANTPS,
+    F_VGETMANTSD,
+    F_VGETMANTSS,
+    F_VINSERTF32X4,
+    F_VINSERTF64X2,
+    F_VINSERTF32X8,
+    F_VINSERTF64X4,
+    F_VINSERTI32X4,
+    F_VINSERTI64X2,
+    F_VINSERTI32X8,
+    F_VINSERTI64X4,
+    F_VPBLENDMB,
+    F_VPBLENDMW,
+    F_VPBLENDMD,
+    F_VPBLENDMQ,
     F_VZEROALL,
     F_VZEROUPPER,
     F_VPCOMB,
@@ -1224,7 +1493,39 @@ typedef enum fcml_en_instruction {
     F_XTEST,
     F_RDSEED,
     F_CLAC,
-    F_STAC
+    F_STAC,
+    F_V4FMADDPS,
+    F_V4FNMADDPS,
+    F_V4FMADDSS,
+    F_V4FNMADDSS,
+    F_VEXP2PD,
+    F_VEXP2PS,
+    F_VGATHERPF0DPS,
+    F_VGATHERPF0QPS,
+    F_VGATHERPF0DPD,
+    F_VGATHERPF0QPD,
+    F_VGATHERPF1DPS,
+    F_VGATHERPF1QPS,
+    F_VGATHERPF1DPD,
+    F_VGATHERPF1QPD,
+    F_VP4DPWSSDS,
+    F_VP4DPWSSD,
+    F_VRCP28PD,
+    F_VRCP28SD,
+    F_VRCP28PS,
+    F_VRCP28SS,
+    F_VRSQRT28PD,
+    F_VRSQRT28SD,
+    F_VRSQRT28PS,
+    F_VRSQRT28SS,
+    F_VSCATTERPF0DPS,
+    F_VSCATTERPF0QPS,
+    F_VSCATTERPF0DPD,
+    F_VSCATTERPF0QPD,
+    F_VSCATTERPF1DPS,
+    F_VSCATTERPF1QPS,
+    F_VSCATTERPF1DPD,
+    F_VSCATTERPF1QPD
 } fcml_en_instruction;
 
 /** @} */
