@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2019 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -94,49 +94,62 @@
 #define M_CLI FCML_TEXT("cli")
 #define M_CLTS FCML_TEXT("clts")
 #define M_CMC FCML_TEXT("cmc")
-#define M_CMOVO   FCML_TEXT("cmovo");
-#define M_CMOVNO  FCML_TEXT("cmovno");
-#define M_CMOVB   FCML_TEXT("cmovb");
-#define M_CMOVNB  FCML_TEXT("cmovnb");
-#define M_CMOVE   FCML_TEXT("cmove");
-#define M_CMOVNE  FCML_TEXT("cmovne");
-#define M_CMOVBE  FCML_TEXT("cmovbe");
-#define M_CMOVNBE FCML_TEXT("cmovnbe");
-#define M_CMOVS   FCML_TEXT("cmovs");
-#define M_CMOVNS  FCML_TEXT("cmovns");
-#define M_CMOVP   FCML_TEXT("cmovp");
-#define M_CMOVNP  FCML_TEXT("cmovnp");
-#define M_CMOVL   FCML_TEXT("cmovl");
-#define M_CMOVNL  FCML_TEXT("cmovnl");
-#define M_CMOVLE  FCML_TEXT("cmovle");
-#define M_CMOVNLE FCML_TEXT("cmovnle");
-#define M_CMOVNAE FCML_TEXT("cmovnae");
-#define M_CMOVAE  FCML_TEXT("cmovae");
-#define M_CMOVZ   FCML_TEXT("cmovz");
-#define M_CMOVNZ  FCML_TEXT("cmovnz");
-#define M_CMOVNA  FCML_TEXT("cmovna");
-#define M_CMOVA   FCML_TEXT("cmova");
-#define M_CMOVPE  FCML_TEXT("cmovpe");
-#define M_CMOVPO  FCML_TEXT("cmovpo");
-#define M_CMOVNGE FCML_TEXT("cmovnge");
-#define M_CMOVGE  FCML_TEXT("cmovge");
-#define M_CMOVNG  FCML_TEXT("cmovng");
-#define M_CMOVG   FCML_TEXT("cmovg");
-#define M_CMOVC   FCML_TEXT("cmovc");
-#define M_CMOVNC  FCML_TEXT("cmovnc");
+#define M_CMOVA FCML_TEXT("cmova")
+#define M_CMOVAE FCML_TEXT("cmovae")
+#define M_CMOVB FCML_TEXT("cmovb")
+#define M_CMOVBE FCML_TEXT("cmovbe")
+#define M_CMOVC FCML_TEXT("cmovc")
+#define M_CMOVENE FCML_TEXT("cmovene")
+#define M_CMOVG FCML_TEXT("cmovg")
+#define M_CMOVGE FCML_TEXT("cmovge")
+#define M_CMOVL FCML_TEXT("cmovl")
+#define M_CMOVLE FCML_TEXT("cmovle")
+#define M_CMOVNA FCML_TEXT("cmovna")
+#define M_CMOVNAE FCML_TEXT("cmovnae")
+#define M_CMOVNB FCML_TEXT("cmovnb")
+#define M_CMOVNBE FCML_TEXT("cmovnbe")
+#define M_CMOVNC FCML_TEXT("cmovnc")
+#define M_CMOVNG FCML_TEXT("cmovng")
+#define M_CMOVNGE FCML_TEXT("cmovnge")
+#define M_CMOVNL FCML_TEXT("cmovnl")
+#define M_CMOVNLE FCML_TEXT("cmovnle")
+#define M_CMOVNO FCML_TEXT("cmovno")
+#define M_CMOVNP FCML_TEXT("cmovnp")
+#define M_CMOVNS FCML_TEXT("cmovns")
+#define M_CMOVNZ FCML_TEXT("cmovnz")
+#define M_CMOVO FCML_TEXT("cmovo")
+#define M_CMOVP FCML_TEXT("cmovp")
+#define M_CMOVPE FCML_TEXT("cmovpe")
+#define M_CMOVPO FCML_TEXT("cmovpo")
+#define M_CMOVS FCML_TEXT("cmovs")
+#define M_CMOVZ FCML_TEXT("cmovz")
 #define M_CMP FCML_TEXT("cmp")
+#define M_CMPEQPD FCML_TEXT("cmpeqpd")
+#define M_CMPEQPS FCML_TEXT("cmpeqps")
 #define M_CMPEQSD FCML_TEXT("cmpeqsd")
 #define M_CMPEQSS FCML_TEXT("cmpeqss")
+#define M_CMPLEPD FCML_TEXT("cmplepd")
+#define M_CMPLEPS FCML_TEXT("cmpleps")
 #define M_CMPLESD FCML_TEXT("cmplesd")
 #define M_CMPLESS FCML_TEXT("cmpless")
+#define M_CMPLTPD FCML_TEXT("cmpltpd")
+#define M_CMPLTPS FCML_TEXT("cmpltps")
 #define M_CMPLTSD FCML_TEXT("cmpltsd")
 #define M_CMPLTSS FCML_TEXT("cmpltss")
+#define M_CMPNEQPD FCML_TEXT("cmpneqpd")
+#define M_CMPNEQPS FCML_TEXT("cmpneqps")
 #define M_CMPNEQSD FCML_TEXT("cmpneqsd")
 #define M_CMPNEQSS FCML_TEXT("cmpneqss")
+#define M_CMPNLEPD FCML_TEXT("cmpnlepd")
+#define M_CMPNLEPS FCML_TEXT("cmpnleps")
 #define M_CMPNLESD FCML_TEXT("cmpnlesd")
 #define M_CMPNLESS FCML_TEXT("cmpnless")
+#define M_CMPNLTPD FCML_TEXT("cmpnltpd")
+#define M_CMPNLTPS FCML_TEXT("cmpnltps")
 #define M_CMPNLTSD FCML_TEXT("cmpnltsd")
 #define M_CMPNLTSS FCML_TEXT("cmpnltss")
+#define M_CMPORDPD FCML_TEXT("cmpordpd")
+#define M_CMPORDPS FCML_TEXT("cmpordps")
 #define M_CMPORDSD FCML_TEXT("cmpordsd")
 #define M_CMPORDSS FCML_TEXT("cmpordss")
 #define M_CMPPD FCML_TEXT("cmppd")
@@ -147,6 +160,8 @@
 #define M_CMPSQ FCML_TEXT("cmpsq")
 #define M_CMPSS FCML_TEXT("cmpss")
 #define M_CMPSW FCML_TEXT("cmpsw")
+#define M_CMPUNORDPD FCML_TEXT("cmpunordpd")
+#define M_CMPUNORDPS FCML_TEXT("cmpunordps")
 #define M_CMPUNORDSD FCML_TEXT("cmpunordsd")
 #define M_CMPUNORDSS FCML_TEXT("cmpunordss")
 #define M_CMPXCHG FCML_TEXT("cmpxchg")
@@ -321,40 +336,87 @@
 #define M_IRET FCML_TEXT("iret")
 #define M_IRETD FCML_TEXT("iretd")
 #define M_IRETQ FCML_TEXT("iretq")
-#define M_JO   FCML_TEXT("jo");
-#define M_JNO  FCML_TEXT("jno");
-#define M_JB   FCML_TEXT("jb");
-#define M_JNB  FCML_TEXT("jnb");
-#define M_JE   FCML_TEXT("je");
-#define M_JNE  FCML_TEXT("jne");
-#define M_JBE  FCML_TEXT("jbe");
-#define M_JNBE FCML_TEXT("jnbe");
-#define M_JS   FCML_TEXT("js");
-#define M_JNS  FCML_TEXT("jns");
-#define M_JP   FCML_TEXT("jp");
-#define M_JNP  FCML_TEXT("jnp");
-#define M_JL   FCML_TEXT("jl");
-#define M_JNL  FCML_TEXT("jnl");
-#define M_JLE  FCML_TEXT("jle");
-#define M_JNLE FCML_TEXT("jnle");
-#define M_JNAE FCML_TEXT("jnae");
-#define M_JAE  FCML_TEXT("jae");
-#define M_JZ   FCML_TEXT("jz");
-#define M_JNZ  FCML_TEXT("jnz");
-#define M_JNA  FCML_TEXT("jna");
-#define M_JA   FCML_TEXT("ja");
-#define M_JPE  FCML_TEXT("jpe");
-#define M_JPO  FCML_TEXT("jpo");
-#define M_JNGE FCML_TEXT("jnge");
-#define M_JGE  FCML_TEXT("jge");
-#define M_JNG  FCML_TEXT("jng");
-#define M_JG   FCML_TEXT("jg");
-#define M_JC   FCML_TEXT("jc");
-#define M_JNC  FCML_TEXT("jnc");
+#define M_JA FCML_TEXT("ja")
+#define M_JAE FCML_TEXT("jae")
+#define M_JB FCML_TEXT("jb")
+#define M_JBE FCML_TEXT("jbe")
+#define M_JC FCML_TEXT("jc")
 #define M_JCXZ FCML_TEXT("jcxz")
 #define M_JECXZ FCML_TEXT("jecxz")
+#define M_JENE FCML_TEXT("jene")
+#define M_JG FCML_TEXT("jg")
+#define M_JGE FCML_TEXT("jge")
+#define M_JL FCML_TEXT("jl")
+#define M_JLE FCML_TEXT("jle")
 #define M_JMP FCML_TEXT("jmp")
+#define M_JNA FCML_TEXT("jna")
+#define M_JNAE FCML_TEXT("jnae")
+#define M_JNB FCML_TEXT("jnb")
+#define M_JNBE FCML_TEXT("jnbe")
+#define M_JNC FCML_TEXT("jnc")
+#define M_JNG FCML_TEXT("jng")
+#define M_JNGE FCML_TEXT("jnge")
+#define M_JNL FCML_TEXT("jnl")
+#define M_JNLE FCML_TEXT("jnle")
+#define M_JNO FCML_TEXT("jno")
+#define M_JNP FCML_TEXT("jnp")
+#define M_JNS FCML_TEXT("jns")
+#define M_JNZ FCML_TEXT("jnz")
+#define M_JO FCML_TEXT("jo")
+#define M_JP FCML_TEXT("jp")
+#define M_JPE FCML_TEXT("jpe")
+#define M_JPO FCML_TEXT("jpo")
 #define M_JRCXZ FCML_TEXT("jrcxz")
+#define M_JS FCML_TEXT("js")
+#define M_JZ FCML_TEXT("jz")
+#define M_KADDB FCML_TEXT("kaddb")
+#define M_KADDD FCML_TEXT("kaddd")
+#define M_KADDQ FCML_TEXT("kaddq")
+#define M_KADDW FCML_TEXT("kaddw")
+#define M_KANDB FCML_TEXT("kandb")
+#define M_KANDD FCML_TEXT("kandd")
+#define M_KANDNB FCML_TEXT("kandnb")
+#define M_KANDND FCML_TEXT("kandnd")
+#define M_KANDNQ FCML_TEXT("kandnq")
+#define M_KANDNW FCML_TEXT("kandnw")
+#define M_KANDQ FCML_TEXT("kandq")
+#define M_KANDW FCML_TEXT("kandw")
+#define M_KMOVB FCML_TEXT("kmovb")
+#define M_KMOVD FCML_TEXT("kmovd")
+#define M_KMOVQ FCML_TEXT("kmovq")
+#define M_KMOVW FCML_TEXT("kmovw")
+#define M_KNOTB FCML_TEXT("knotb")
+#define M_KNOTD FCML_TEXT("knotd")
+#define M_KNOTQ FCML_TEXT("knotq")
+#define M_KNOTW FCML_TEXT("knotw")
+#define M_KORB FCML_TEXT("korb")
+#define M_KORD FCML_TEXT("kord")
+#define M_KORQ FCML_TEXT("korq")
+#define M_KORTESTB FCML_TEXT("kortestb")
+#define M_KORTESTD FCML_TEXT("kortestd")
+#define M_KORTESTQ FCML_TEXT("kortestq")
+#define M_KORTESTW FCML_TEXT("kortestw")
+#define M_KORW FCML_TEXT("korw")
+#define M_KSHIFTLB FCML_TEXT("kshiftlb")
+#define M_KSHIFTLD FCML_TEXT("kshiftld")
+#define M_KSHIFTLQ FCML_TEXT("kshiftlq")
+#define M_KSHIFTLW FCML_TEXT("kshiftlw")
+#define M_KSHIFTRB FCML_TEXT("kshiftrb")
+#define M_KSHIFTRD FCML_TEXT("kshiftrd")
+#define M_KSHIFTRQ FCML_TEXT("kshiftrq")
+#define M_KSHIFTRW FCML_TEXT("kshiftrw")
+#define M_KTESTB FCML_TEXT("ktestb")
+#define M_KTESTD FCML_TEXT("ktestd")
+#define M_KTESTQ FCML_TEXT("ktestq")
+#define M_KTESTW FCML_TEXT("ktestw")
+#define M_KXNORB FCML_TEXT("kxnorb")
+#define M_KXNORD FCML_TEXT("kxnord")
+#define M_KXNORQ FCML_TEXT("kxnorq")
+#define M_KXNORW FCML_TEXT("kxnorw")
+#define M_KXORB FCML_TEXT("kxorb")
+#define M_KXORD FCML_TEXT("kxord")
+#define M_KXORQ FCML_TEXT("kxorq")
+#define M_KXORW FCML_TEXT("kxorw")
 #define M_LAHF FCML_TEXT("lahf")
 #define M_LAR FCML_TEXT("lar")
 #define M_LDDQU FCML_TEXT("lddqu")
@@ -582,6 +644,7 @@
 #define M_PREFETCHT1 FCML_TEXT("prefetcht1")
 #define M_PREFETCHT2 FCML_TEXT("prefetcht2")
 #define M_PREFETCHW FCML_TEXT("prefetchw")
+#define M_PREFETCHWT1 FCML_TEXT("prefetchwt1")
 #define M_PSADBW FCML_TEXT("psadbw")
 #define M_PSHUFB FCML_TEXT("pshufb")
 #define M_PSHUFD FCML_TEXT("pshufd")
@@ -660,36 +723,35 @@
 #define M_SCASD FCML_TEXT("scasd")
 #define M_SCASQ FCML_TEXT("scasq")
 #define M_SCASW FCML_TEXT("scasw")
-#define M_SETO   FCML_TEXT("seto");
-#define M_SETNO  FCML_TEXT("setno");
-#define M_SETB   FCML_TEXT("setb");
-#define M_SETNB  FCML_TEXT("setnb");
-#define M_SETE   FCML_TEXT("sete");
-#define M_SETNE  FCML_TEXT("setne");
-#define M_SETBE  FCML_TEXT("setbe");
-#define M_SETNBE FCML_TEXT("setnbe");
-#define M_SETS   FCML_TEXT("sets");
-#define M_SETNS  FCML_TEXT("setns");
-#define M_SETP   FCML_TEXT("setp");
-#define M_SETNP  FCML_TEXT("setnp");
-#define M_SETL   FCML_TEXT("setl");
-#define M_SETNL  FCML_TEXT("setnl");
-#define M_SETLE  FCML_TEXT("setle");
-#define M_SETNLE FCML_TEXT("setnle");
-#define M_SETNAE FCML_TEXT("setnae");
-#define M_SETAE  FCML_TEXT("setae");
-#define M_SETZ   FCML_TEXT("setz");
-#define M_SETNZ  FCML_TEXT("setnz");
-#define M_SETNA  FCML_TEXT("setna");
-#define M_SETA   FCML_TEXT("seta");
-#define M_SETPE  FCML_TEXT("setpe");
-#define M_SETPO  FCML_TEXT("setpo");
-#define M_SETNGE FCML_TEXT("setnge");
-#define M_SETGE  FCML_TEXT("setge");
-#define M_SETNG  FCML_TEXT("setng");
-#define M_SETG   FCML_TEXT("setg");
-#define M_SETC   FCML_TEXT("setc");
-#define M_SETNC  FCML_TEXT("setnc");
+#define M_SETA FCML_TEXT("seta")
+#define M_SETAE FCML_TEXT("setae")
+#define M_SETB FCML_TEXT("setb")
+#define M_SETBE FCML_TEXT("setbe")
+#define M_SETC FCML_TEXT("setc")
+#define M_SETENE FCML_TEXT("setene")
+#define M_SETG FCML_TEXT("setg")
+#define M_SETGE FCML_TEXT("setge")
+#define M_SETL FCML_TEXT("setl")
+#define M_SETLE FCML_TEXT("setle")
+#define M_SETNA FCML_TEXT("setna")
+#define M_SETNAE FCML_TEXT("setnae")
+#define M_SETNB FCML_TEXT("setnb")
+#define M_SETNBE FCML_TEXT("setnbe")
+#define M_SETNC FCML_TEXT("setnc")
+#define M_SETNG FCML_TEXT("setng")
+#define M_SETNGE FCML_TEXT("setnge")
+#define M_SETNL FCML_TEXT("setnl")
+#define M_SETNLE FCML_TEXT("setnle")
+#define M_SETNO FCML_TEXT("setno")
+#define M_SETNP FCML_TEXT("setnp")
+#define M_SETNS FCML_TEXT("setns")
+#define M_SETNZ FCML_TEXT("setnz")
+#define M_SETO FCML_TEXT("seto")
+#define M_SETP FCML_TEXT("setp")
+#define M_SETPE FCML_TEXT("setpe")
+#define M_SETPO FCML_TEXT("setpo")
+#define M_SETS FCML_TEXT("sets")
+#define M_SETZ FCML_TEXT("setz")
 #define M_SFENCE FCML_TEXT("sfence")
 #define M_SGDT FCML_TEXT("sgdt")
 #define M_SHL FCML_TEXT("shl")
@@ -742,6 +804,10 @@
 #define M_UNPCKHPS FCML_TEXT("unpckhps")
 #define M_UNPCKLPD FCML_TEXT("unpcklpd")
 #define M_UNPCKLPS FCML_TEXT("unpcklps")
+#define M_V4FMADDPS FCML_TEXT("v4fmaddps")
+#define M_V4FMADDSS FCML_TEXT("v4fmaddss")
+#define M_V4FNMADDPS FCML_TEXT("v4fnmaddps")
+#define M_V4FNMADDSS FCML_TEXT("v4fnmaddss")
 #define M_VADDPD FCML_TEXT("vaddpd")
 #define M_VADDPS FCML_TEXT("vaddps")
 #define M_VADDSD FCML_TEXT("vaddsd")
@@ -754,106 +820,211 @@
 #define M_VAESENCLAST FCML_TEXT("vaesenclast")
 #define M_VAESIMC FCML_TEXT("vaesimc")
 #define M_VAESKEYGENASSIST FCML_TEXT("vaeskeygenassist")
+#define M_VALIGND FCML_TEXT("valignd")
+#define M_VALIGNQ FCML_TEXT("valignq")
 #define M_VANDNPD FCML_TEXT("vandnpd")
 #define M_VANDNPS FCML_TEXT("vandnps")
 #define M_VANDPD FCML_TEXT("vandpd")
 #define M_VANDPS FCML_TEXT("vandps")
+#define M_VBLENDMPD FCML_TEXT("vblendmpd")
+#define M_VBLENDMPS FCML_TEXT("vblendmps")
 #define M_VBLENDPD FCML_TEXT("vblendpd")
 #define M_VBLENDPS FCML_TEXT("vblendps")
 #define M_VBLENDVPD FCML_TEXT("vblendvpd")
 #define M_VBLENDVPS FCML_TEXT("vblendvps")
 #define M_VBROADCASTF128 FCML_TEXT("vbroadcastf128")
+#define M_VBROADCASTF32X2 FCML_TEXT("vbroadcastf32x2")
+#define M_VBROADCASTF32X4 FCML_TEXT("vbroadcastf32x4")
+#define M_VBROADCASTF32X8 FCML_TEXT("vbroadcastf32x8")
+#define M_VBROADCASTF64X2 FCML_TEXT("vbroadcastf64x2")
+#define M_VBROADCASTF64X4 FCML_TEXT("vbroadcastf64x4")
 #define M_VBROADCASTI128 FCML_TEXT("vbroadcasti128")
+#define M_VBROADCASTI32X2 FCML_TEXT("vbroadcasti32x2")
+#define M_VBROADCASTI32X4 FCML_TEXT("vbroadcasti32x4")
+#define M_VBROADCASTI32X8 FCML_TEXT("vbroadcasti32x8")
+#define M_VBROADCASTI64X2 FCML_TEXT("vbroadcasti64x2")
+#define M_VBROADCASTI64X4 FCML_TEXT("vbroadcasti64x4")
 #define M_VBROADCASTSD FCML_TEXT("vbroadcastsd")
 #define M_VBROADCASTSS FCML_TEXT("vbroadcastss")
+#define M_VCMPEQ_OSPD FCML_TEXT("vcmpeq_ospd")
+#define M_VCMPEQ_OSPS FCML_TEXT("vcmpeq_osps")
 #define M_VCMPEQ_OSSD FCML_TEXT("vcmpeq_ossd")
 #define M_VCMPEQ_OSSS FCML_TEXT("vcmpeq_osss")
-#define M_VCMPEQSD FCML_TEXT("vcmpeqsd")
-#define M_VCMPEQSS FCML_TEXT("vcmpeqss")
+#define M_VCMPEQ_UQPD FCML_TEXT("vcmpeq_uqpd")
+#define M_VCMPEQ_UQPS FCML_TEXT("vcmpeq_uqps")
 #define M_VCMPEQ_UQSD FCML_TEXT("vcmpeq_uqsd")
 #define M_VCMPEQ_UQSS FCML_TEXT("vcmpeq_uqss")
+#define M_VCMPEQ_USPD FCML_TEXT("vcmpeq_uspd")
+#define M_VCMPEQ_USPS FCML_TEXT("vcmpeq_usps")
 #define M_VCMPEQ_USSD FCML_TEXT("vcmpeq_ussd")
 #define M_VCMPEQ_USSS FCML_TEXT("vcmpeq_usss")
+#define M_VCMPEQPD FCML_TEXT("vcmpeqpd")
+#define M_VCMPEQPS FCML_TEXT("vcmpeqps")
+#define M_VCMPEQSD FCML_TEXT("vcmpeqsd")
+#define M_VCMPEQSS FCML_TEXT("vcmpeqss")
+#define M_VCMPFALSE_OSPD FCML_TEXT("vcmpfalse_ospd")
+#define M_VCMPFALSE_OSPS FCML_TEXT("vcmpfalse_osps")
 #define M_VCMPFALSE_OSSD FCML_TEXT("vcmpfalse_ossd")
 #define M_VCMPFALSE_OSSS FCML_TEXT("vcmpfalse_osss")
+#define M_VCMPFALSEPD FCML_TEXT("vcmpfalsepd")
+#define M_VCMPFALSEPS FCML_TEXT("vcmpfalseps")
 #define M_VCMPFALSESD FCML_TEXT("vcmpfalsesd")
 #define M_VCMPFALSESS FCML_TEXT("vcmpfalsess")
+#define M_VCMPGE_OQPD FCML_TEXT("vcmpge_oqpd")
+#define M_VCMPGE_OQPS FCML_TEXT("vcmpge_oqps")
 #define M_VCMPGE_OQSD FCML_TEXT("vcmpge_oqsd")
 #define M_VCMPGE_OQSS FCML_TEXT("vcmpge_oqss")
+#define M_VCMPGEPD FCML_TEXT("vcmpgepd")
+#define M_VCMPGEPS FCML_TEXT("vcmpgeps")
 #define M_VCMPGESD FCML_TEXT("vcmpgesd")
 #define M_VCMPGESS FCML_TEXT("vcmpgess")
+#define M_VCMPGT_OQPD FCML_TEXT("vcmpgt_oqpd")
+#define M_VCMPGT_OQPS FCML_TEXT("vcmpgt_oqps")
 #define M_VCMPGT_OQSD FCML_TEXT("vcmpgt_oqsd")
 #define M_VCMPGT_OQSS FCML_TEXT("vcmpgt_oqss")
+#define M_VCMPGTPD FCML_TEXT("vcmpgtpd")
+#define M_VCMPGTPS FCML_TEXT("vcmpgtps")
 #define M_VCMPGTSD FCML_TEXT("vcmpgtsd")
 #define M_VCMPGTSS FCML_TEXT("vcmpgtss")
+#define M_VCMPLE_OQPD FCML_TEXT("vcmple_oqpd")
+#define M_VCMPLE_OQPS FCML_TEXT("vcmple_oqps")
 #define M_VCMPLE_OQSD FCML_TEXT("vcmple_oqsd")
 #define M_VCMPLE_OQSS FCML_TEXT("vcmple_oqss")
+#define M_VCMPLEPD FCML_TEXT("vcmplepd")
+#define M_VCMPLEPS FCML_TEXT("vcmpleps")
 #define M_VCMPLESD FCML_TEXT("vcmplesd")
 #define M_VCMPLESS FCML_TEXT("vcmpless")
+#define M_VCMPLT_OQPD FCML_TEXT("vcmplt_oqpd")
+#define M_VCMPLT_OQPS FCML_TEXT("vcmplt_oqps")
 #define M_VCMPLT_OQSD FCML_TEXT("vcmplt_oqsd")
 #define M_VCMPLT_OQSS FCML_TEXT("vcmplt_oqss")
+#define M_VCMPLTPD FCML_TEXT("vcmpltpd")
+#define M_VCMPLTPS FCML_TEXT("vcmpltps")
 #define M_VCMPLTSD FCML_TEXT("vcmpltsd")
 #define M_VCMPLTSS FCML_TEXT("vcmpltss")
+#define M_VCMPNEQ_OQPD FCML_TEXT("vcmpneq_oqpd")
+#define M_VCMPNEQ_OQPS FCML_TEXT("vcmpneq_oqps")
 #define M_VCMPNEQ_OQSD FCML_TEXT("vcmpneq_oqsd")
 #define M_VCMPNEQ_OQSS FCML_TEXT("vcmpneq_oqss")
+#define M_VCMPNEQ_OSPD FCML_TEXT("vcmpneq_ospd")
+#define M_VCMPNEQ_OSPS FCML_TEXT("vcmpneq_osps")
 #define M_VCMPNEQ_OSSD FCML_TEXT("vcmpneq_ossd")
 #define M_VCMPNEQ_OSSS FCML_TEXT("vcmpneq_osss")
-#define M_VCMPNEQSD FCML_TEXT("vcmpneqsd")
-#define M_VCMPNEQSS FCML_TEXT("vcmpneqss")
+#define M_VCMPNEQ_USPD FCML_TEXT("vcmpneq_uspd")
+#define M_VCMPNEQ_USPS FCML_TEXT("vcmpneq_usps")
 #define M_VCMPNEQ_USSD FCML_TEXT("vcmpneq_ussd")
 #define M_VCMPNEQ_USSS FCML_TEXT("vcmpneq_usss")
-#define M_VCMPNGESD FCML_TEXT("vcmpngesd")
-#define M_VCMPNGESS FCML_TEXT("vcmpngess")
+#define M_VCMPNEQPD FCML_TEXT("vcmpneqpd")
+#define M_VCMPNEQPS FCML_TEXT("vcmpneqps")
+#define M_VCMPNEQSD FCML_TEXT("vcmpneqsd")
+#define M_VCMPNEQSS FCML_TEXT("vcmpneqss")
+#define M_VCMPNGE_UQPD FCML_TEXT("vcmpnge_uqpd")
+#define M_VCMPNGE_UQPS FCML_TEXT("vcmpnge_uqps")
 #define M_VCMPNGE_UQSD FCML_TEXT("vcmpnge_uqsd")
 #define M_VCMPNGE_UQSS FCML_TEXT("vcmpnge_uqss")
-#define M_VCMPNGTSD FCML_TEXT("vcmpngtsd")
-#define M_VCMPNGTSS FCML_TEXT("vcmpngtss")
+#define M_VCMPNGEPD FCML_TEXT("vcmpngepd")
+#define M_VCMPNGEPS FCML_TEXT("vcmpngeps")
+#define M_VCMPNGESD FCML_TEXT("vcmpngesd")
+#define M_VCMPNGESS FCML_TEXT("vcmpngess")
+#define M_VCMPNGT_UQPD FCML_TEXT("vcmpngt_uqpd")
+#define M_VCMPNGT_UQPS FCML_TEXT("vcmpngt_uqps")
 #define M_VCMPNGT_UQSD FCML_TEXT("vcmpngt_uqsd")
 #define M_VCMPNGT_UQSS FCML_TEXT("vcmpngt_uqss")
-#define M_VCMPNLESD FCML_TEXT("vcmpnlesd")
-#define M_VCMPNLESS FCML_TEXT("vcmpnless")
+#define M_VCMPNGTPD FCML_TEXT("vcmpngtpd")
+#define M_VCMPNGTPS FCML_TEXT("vcmpngtps")
+#define M_VCMPNGTSD FCML_TEXT("vcmpngtsd")
+#define M_VCMPNGTSS FCML_TEXT("vcmpngtss")
+#define M_VCMPNLE_UQPD FCML_TEXT("vcmpnle_uqpd")
+#define M_VCMPNLE_UQPS FCML_TEXT("vcmpnle_uqps")
 #define M_VCMPNLE_UQSD FCML_TEXT("vcmpnle_uqsd")
 #define M_VCMPNLE_UQSS FCML_TEXT("vcmpnle_uqss")
-#define M_VCMPNLTSD FCML_TEXT("vcmpnltsd")
-#define M_VCMPNLTSS FCML_TEXT("vcmpnltss")
+#define M_VCMPNLEPD FCML_TEXT("vcmpnlepd")
+#define M_VCMPNLEPS FCML_TEXT("vcmpnleps")
+#define M_VCMPNLESD FCML_TEXT("vcmpnlesd")
+#define M_VCMPNLESS FCML_TEXT("vcmpnless")
+#define M_VCMPNLT_UQPD FCML_TEXT("vcmpnlt_uqpd")
+#define M_VCMPNLT_UQPS FCML_TEXT("vcmpnlt_uqps")
 #define M_VCMPNLT_UQSD FCML_TEXT("vcmpnlt_uqsd")
 #define M_VCMPNLT_UQSS FCML_TEXT("vcmpnlt_uqss")
-#define M_VCMPORDSD FCML_TEXT("vcmpordsd")
-#define M_VCMPORDSS FCML_TEXT("vcmpordss")
+#define M_VCMPNLTPD FCML_TEXT("vcmpnltpd")
+#define M_VCMPNLTPS FCML_TEXT("vcmpnltps")
+#define M_VCMPNLTSD FCML_TEXT("vcmpnltsd")
+#define M_VCMPNLTSS FCML_TEXT("vcmpnltss")
+#define M_VCMPORD_SPD FCML_TEXT("vcmpord_spd")
+#define M_VCMPORD_SPS FCML_TEXT("vcmpord_sps")
 #define M_VCMPORD_SSD FCML_TEXT("vcmpord_ssd")
 #define M_VCMPORD_SSS FCML_TEXT("vcmpord_sss")
+#define M_VCMPORDPD FCML_TEXT("vcmpordpd")
+#define M_VCMPORDPS FCML_TEXT("vcmpordps")
+#define M_VCMPORDSD FCML_TEXT("vcmpordsd")
+#define M_VCMPORDSS FCML_TEXT("vcmpordss")
 #define M_VCMPPD FCML_TEXT("vcmppd")
 #define M_VCMPPS FCML_TEXT("vcmpps")
 #define M_VCMPSD FCML_TEXT("vcmpsd")
 #define M_VCMPSS FCML_TEXT("vcmpss")
-#define M_VCMPTRUESD FCML_TEXT("vcmptruesd")
-#define M_VCMPTRUESS FCML_TEXT("vcmptruess")
+#define M_VCMPTRUE_USPD FCML_TEXT("vcmptrue_uspd")
+#define M_VCMPTRUE_USPS FCML_TEXT("vcmptrue_usps")
 #define M_VCMPTRUE_USSD FCML_TEXT("vcmptrue_ussd")
 #define M_VCMPTRUE_USSS FCML_TEXT("vcmptrue_usss")
-#define M_VCMPUNORDSD FCML_TEXT("vcmpunordsd")
-#define M_VCMPUNORDSS FCML_TEXT("vcmpunordss")
+#define M_VCMPTRUEPD FCML_TEXT("vcmptruepd")
+#define M_VCMPTRUEPS FCML_TEXT("vcmptrueps")
+#define M_VCMPTRUESD FCML_TEXT("vcmptruesd")
+#define M_VCMPTRUESS FCML_TEXT("vcmptruess")
+#define M_VCMPUNORD_SPD FCML_TEXT("vcmpunord_spd")
+#define M_VCMPUNORD_SPS FCML_TEXT("vcmpunord_sps")
 #define M_VCMPUNORD_SSD FCML_TEXT("vcmpunord_ssd")
 #define M_VCMPUNORD_SSS FCML_TEXT("vcmpunord_sss")
+#define M_VCMPUNORDPD FCML_TEXT("vcmpunordpd")
+#define M_VCMPUNORDPS FCML_TEXT("vcmpunordps")
+#define M_VCMPUNORDSD FCML_TEXT("vcmpunordsd")
+#define M_VCMPUNORDSS FCML_TEXT("vcmpunordss")
 #define M_VCOMISD FCML_TEXT("vcomisd")
 #define M_VCOMISS FCML_TEXT("vcomiss")
+#define M_VCOMPRESSPD FCML_TEXT("vcompresspd")
+#define M_VCOMPRESSPS FCML_TEXT("vcompressps")
 #define M_VCVTDQ2PD FCML_TEXT("vcvtdq2pd")
 #define M_VCVTDQ2PS FCML_TEXT("vcvtdq2ps")
 #define M_VCVTPD2DQ FCML_TEXT("vcvtpd2dq")
 #define M_VCVTPD2PS FCML_TEXT("vcvtpd2ps")
+#define M_VCVTPD2QQ FCML_TEXT("vcvtpd2qq")
+#define M_VCVTPD2UDQ FCML_TEXT("vcvtpd2udq")
+#define M_VCVTPD2UQQ FCML_TEXT("vcvtpd2uqq")
 #define M_VCVTPH2PS FCML_TEXT("vcvtph2ps")
 #define M_VCVTPS2DQ FCML_TEXT("vcvtps2dq")
 #define M_VCVTPS2PD FCML_TEXT("vcvtps2pd")
 #define M_VCVTPS2PH FCML_TEXT("vcvtps2ph")
+#define M_VCVTPS2QQ FCML_TEXT("vcvtps2qq")
+#define M_VCVTPS2UDQ FCML_TEXT("vcvtps2udq")
+#define M_VCVTPS2UQQ FCML_TEXT("vcvtps2uqq")
+#define M_VCVTQQ2PD FCML_TEXT("vcvtqq2pd")
+#define M_VCVTQQ2PS FCML_TEXT("vcvtqq2ps")
 #define M_VCVTSD2SI FCML_TEXT("vcvtsd2si")
 #define M_VCVTSD2SS FCML_TEXT("vcvtsd2ss")
+#define M_VCVTSD2USI FCML_TEXT("vcvtsd2usi")
 #define M_VCVTSI2SD FCML_TEXT("vcvtsi2sd")
 #define M_VCVTSI2SS FCML_TEXT("vcvtsi2ss")
 #define M_VCVTSS2SD FCML_TEXT("vcvtss2sd")
 #define M_VCVTSS2SI FCML_TEXT("vcvtss2si")
+#define M_VCVTSS2USI FCML_TEXT("vcvtss2usi")
 #define M_VCVTTPD2DQ FCML_TEXT("vcvttpd2dq")
+#define M_VCVTTPD2QQ FCML_TEXT("vcvttpd2qq")
+#define M_VCVTTPD2UDQ FCML_TEXT("vcvttpd2udq")
+#define M_VCVTTPD2UQQ FCML_TEXT("vcvttpd2uqq")
 #define M_VCVTTPS2DQ FCML_TEXT("vcvttps2dq")
+#define M_VCVTTPS2QQ FCML_TEXT("vcvttps2qq")
+#define M_VCVTTPS2UDQ FCML_TEXT("vcvttps2udq")
+#define M_VCVTTPS2UQQ FCML_TEXT("vcvttps2uqq")
 #define M_VCVTTSD2SI FCML_TEXT("vcvttsd2si")
+#define M_VCVTTSD2USI FCML_TEXT("vcvttsd2usi")
 #define M_VCVTTSS2SI FCML_TEXT("vcvttss2si")
+#define M_VCVTTSS2USI FCML_TEXT("vcvttss2usi")
+#define M_VCVTUDQ2PD FCML_TEXT("vcvtudq2pd")
+#define M_VCVTUDQ2PS FCML_TEXT("vcvtudq2ps")
+#define M_VCVTUQQ2PD FCML_TEXT("vcvtuqq2pd")
+#define M_VCVTUQQ2PS FCML_TEXT("vcvtuqq2ps")
+#define M_VCVTUSI2SD FCML_TEXT("vcvtusi2sd")
+#define M_VCVTUSI2SS FCML_TEXT("vcvtusi2ss")
+#define M_VDBPSADBW FCML_TEXT("vdbpsadbw")
 #define M_VDIVPD FCML_TEXT("vdivpd")
 #define M_VDIVPS FCML_TEXT("vdivps")
 #define M_VDIVSD FCML_TEXT("vdivsd")
@@ -862,9 +1033,25 @@
 #define M_VDPPS FCML_TEXT("vdpps")
 #define M_VERR FCML_TEXT("verr")
 #define M_VERW FCML_TEXT("verw")
+#define M_VEXP2PD FCML_TEXT("vexp2pd")
+#define M_VEXP2PS FCML_TEXT("vexp2ps")
+#define M_VEXPANDPD FCML_TEXT("vexpandpd")
+#define M_VEXPANDPS FCML_TEXT("vexpandps")
 #define M_VEXTRACTF128 FCML_TEXT("vextractf128")
+#define M_VEXTRACTF32X4 FCML_TEXT("vextractf32x4")
+#define M_VEXTRACTF32X8 FCML_TEXT("vextractf32x8")
+#define M_VEXTRACTF64X2 FCML_TEXT("vextractf64x2")
+#define M_VEXTRACTF64X4 FCML_TEXT("vextractf64x4")
 #define M_VEXTRACTI128 FCML_TEXT("vextracti128")
+#define M_VEXTRACTI32X4 FCML_TEXT("vextracti32x4")
+#define M_VEXTRACTI32X8 FCML_TEXT("vextracti32x8")
+#define M_VEXTRACTI64X2 FCML_TEXT("vextracti64x2")
+#define M_VEXTRACTI64X4 FCML_TEXT("vextracti64x4")
 #define M_VEXTRACTPS FCML_TEXT("vextractps")
+#define M_VFIXUPIMMPD FCML_TEXT("vfixupimmpd")
+#define M_VFIXUPIMMPS FCML_TEXT("vfixupimmps")
+#define M_VFIXUPIMMSD FCML_TEXT("vfixupimmsd")
+#define M_VFIXUPIMMSS FCML_TEXT("vfixupimmss")
 #define M_VFMADD132PD FCML_TEXT("vfmadd132pd")
 #define M_VFMADD132PS FCML_TEXT("vfmadd132ps")
 #define M_VFMADD132SD FCML_TEXT("vfmadd132sd")
@@ -945,20 +1132,48 @@
 #define M_VFNMSUBPS FCML_TEXT("vfnmsubps")
 #define M_VFNMSUBSD FCML_TEXT("vfnmsubsd")
 #define M_VFNMSUBSS FCML_TEXT("vfnmsubss")
+#define M_VFPCLASSPD FCML_TEXT("vfpclasspd")
+#define M_VFPCLASSPS FCML_TEXT("vfpclassps")
+#define M_VFPCLASSSD FCML_TEXT("vfpclasssd")
+#define M_VFPCLASSSS FCML_TEXT("vfpclassss")
 #define M_VFRCZPD FCML_TEXT("vfrczpd")
 #define M_VFRCZPS FCML_TEXT("vfrczps")
 #define M_VFRCZSD FCML_TEXT("vfrczsd")
 #define M_VFRCZSS FCML_TEXT("vfrczss")
 #define M_VGATHERDPD FCML_TEXT("vgatherdpd")
 #define M_VGATHERDPS FCML_TEXT("vgatherdps")
+#define M_VGATHERPF0DPD FCML_TEXT("vgatherpf0dpd")
+#define M_VGATHERPF0DPS FCML_TEXT("vgatherpf0dps")
+#define M_VGATHERPF0QPD FCML_TEXT("vgatherpf0qpd")
+#define M_VGATHERPF0QPS FCML_TEXT("vgatherpf0qps")
+#define M_VGATHERPF1DPD FCML_TEXT("vgatherpf1dpd")
+#define M_VGATHERPF1DPS FCML_TEXT("vgatherpf1dps")
+#define M_VGATHERPF1QPD FCML_TEXT("vgatherpf1qpd")
+#define M_VGATHERPF1QPS FCML_TEXT("vgatherpf1qps")
 #define M_VGATHERQPD FCML_TEXT("vgatherqpd")
 #define M_VGATHERQPS FCML_TEXT("vgatherqps")
+#define M_VGETEXPPD FCML_TEXT("vgetexppd")
+#define M_VGETEXPPS FCML_TEXT("vgetexpps")
+#define M_VGETEXPSD FCML_TEXT("vgetexpsd")
+#define M_VGETEXPSS FCML_TEXT("vgetexpss")
+#define M_VGETMANTPD FCML_TEXT("vgetmantpd")
+#define M_VGETMANTPS FCML_TEXT("vgetmantps")
+#define M_VGETMANTSD FCML_TEXT("vgetmantsd")
+#define M_VGETMANTSS FCML_TEXT("vgetmantss")
 #define M_VHADDPD FCML_TEXT("vhaddpd")
 #define M_VHADDPS FCML_TEXT("vhaddps")
 #define M_VHSUBPD FCML_TEXT("vhsubpd")
 #define M_VHSUBPS FCML_TEXT("vhsubps")
 #define M_VINSERTF128 FCML_TEXT("vinsertf128")
+#define M_VINSERTF32X4 FCML_TEXT("vinsertf32x4")
+#define M_VINSERTF32X8 FCML_TEXT("vinsertf32x8")
+#define M_VINSERTF64X2 FCML_TEXT("vinsertf64x2")
+#define M_VINSERTF64X4 FCML_TEXT("vinsertf64x4")
 #define M_VINSERTI128 FCML_TEXT("vinserti128")
+#define M_VINSERTI32X4 FCML_TEXT("vinserti32x4")
+#define M_VINSERTI32X8 FCML_TEXT("vinserti32x8")
+#define M_VINSERTI64X2 FCML_TEXT("vinserti64x2")
+#define M_VINSERTI64X4 FCML_TEXT("vinserti64x4")
 #define M_VINSERTPS FCML_TEXT("vinsertps")
 #define M_VLDDQU FCML_TEXT("vlddqu")
 #define M_VLDMXCSR FCML_TEXT("vldmxcsr")
@@ -984,7 +1199,13 @@
 #define M_VMOVD FCML_TEXT("vmovd")
 #define M_VMOVDDUP FCML_TEXT("vmovddup")
 #define M_VMOVDQA FCML_TEXT("vmovdqa")
+#define M_VMOVDQA32 FCML_TEXT("vmovdqa32")
+#define M_VMOVDQA64 FCML_TEXT("vmovdqa64")
 #define M_VMOVDQU FCML_TEXT("vmovdqu")
+#define M_VMOVDQU16 FCML_TEXT("vmovdqu16")
+#define M_VMOVDQU32 FCML_TEXT("vmovdqu32")
+#define M_VMOVDQU64 FCML_TEXT("vmovdqu64")
+#define M_VMOVDQU8 FCML_TEXT("vmovdqu8")
 #define M_VMOVHLPS FCML_TEXT("vmovhlps")
 #define M_VMOVHPD FCML_TEXT("vmovhpd")
 #define M_VMOVHPS FCML_TEXT("vmovhps")
@@ -1020,8 +1241,11 @@
 #define M_VMXON FCML_TEXT("vmxon")
 #define M_VORPD FCML_TEXT("vorpd")
 #define M_VORPS FCML_TEXT("vorps")
+#define M_VP4DPWSSD FCML_TEXT("vp4dpwssd")
+#define M_VP4DPWSSDS FCML_TEXT("vp4dpwssds")
 #define M_VPABSB FCML_TEXT("vpabsb")
 #define M_VPABSD FCML_TEXT("vpabsd")
+#define M_VPABSQ FCML_TEXT("vpabsq")
 #define M_VPABSW FCML_TEXT("vpabsw")
 #define M_VPACKSSDW FCML_TEXT("vpackssdw")
 #define M_VPACKSSWB FCML_TEXT("vpacksswb")
@@ -1037,18 +1261,30 @@
 #define M_VPADDW FCML_TEXT("vpaddw")
 #define M_VPALIGNR FCML_TEXT("vpalignr")
 #define M_VPAND FCML_TEXT("vpand")
+#define M_VPANDD FCML_TEXT("vpandd")
 #define M_VPANDN FCML_TEXT("vpandn")
+#define M_VPANDND FCML_TEXT("vpandnd")
+#define M_VPANDNQ FCML_TEXT("vpandnq")
+#define M_VPANDQ FCML_TEXT("vpandq")
 #define M_VPAVGB FCML_TEXT("vpavgb")
 #define M_VPAVGW FCML_TEXT("vpavgw")
 #define M_VPBLENDD FCML_TEXT("vpblendd")
+#define M_VPBLENDMB FCML_TEXT("vpblendmb")
+#define M_VPBLENDMD FCML_TEXT("vpblendmd")
+#define M_VPBLENDMQ FCML_TEXT("vpblendmq")
+#define M_VPBLENDMW FCML_TEXT("vpblendmw")
 #define M_VPBLENDVB FCML_TEXT("vpblendvb")
 #define M_VPBLENDW FCML_TEXT("vpblendw")
 #define M_VPBROADCASTB FCML_TEXT("vpbroadcastb")
 #define M_VPBROADCASTD FCML_TEXT("vpbroadcastd")
+#define M_VPBROADCASTMB2Q FCML_TEXT("vpbroadcastmb2q")
+#define M_VPBROADCASTMW2D FCML_TEXT("vpbroadcastmw2d")
 #define M_VPBROADCASTQ FCML_TEXT("vpbroadcastq")
 #define M_VPBROADCASTW FCML_TEXT("vpbroadcastw")
 #define M_VPCLMULQDQ FCML_TEXT("vpclmulqdq")
 #define M_VPCMOV FCML_TEXT("vpcmov")
+#define M_VPCMPB FCML_TEXT("vpcmpb")
+#define M_VPCMPD FCML_TEXT("vpcmpd")
 #define M_VPCMPEQB FCML_TEXT("vpcmpeqb")
 #define M_VPCMPEQD FCML_TEXT("vpcmpeqd")
 #define M_VPCMPEQQ FCML_TEXT("vpcmpeqq")
@@ -1061,6 +1297,12 @@
 #define M_VPCMPGTW FCML_TEXT("vpcmpgtw")
 #define M_VPCMPISTRI FCML_TEXT("vpcmpistri")
 #define M_VPCMPISTRM FCML_TEXT("vpcmpistrm")
+#define M_VPCMPQ FCML_TEXT("vpcmpq")
+#define M_VPCMPUB FCML_TEXT("vpcmpub")
+#define M_VPCMPUD FCML_TEXT("vpcmpud")
+#define M_VPCMPUQ FCML_TEXT("vpcmpuq")
+#define M_VPCMPUW FCML_TEXT("vpcmpuw")
+#define M_VPCMPW FCML_TEXT("vpcmpw")
 #define M_VPCOMB FCML_TEXT("vpcomb")
 #define M_VPCOMD FCML_TEXT("vpcomd")
 #define M_VPCOMEQB FCML_TEXT("vpcomeqb")
@@ -1119,6 +1361,8 @@
 #define M_VPCOMNEQUQ FCML_TEXT("vpcomnequq")
 #define M_VPCOMNEQUW FCML_TEXT("vpcomnequw")
 #define M_VPCOMNEQW FCML_TEXT("vpcomneqw")
+#define M_VPCOMPRESSD FCML_TEXT("vpcompressd")
+#define M_VPCOMPRESSQ FCML_TEXT("vpcompressq")
 #define M_VPCOMQ FCML_TEXT("vpcomq")
 #define M_VPCOMTRUEB FCML_TEXT("vpcomtrueb")
 #define M_VPCOMTRUED FCML_TEXT("vpcomtrued")
@@ -1135,7 +1379,14 @@
 #define M_VPCOMW FCML_TEXT("vpcomw")
 #define M_VPERM2F128 FCML_TEXT("vperm2f128")
 #define M_VPERM2I128 FCML_TEXT("vperm2i128")
+#define M_VPERMB FCML_TEXT("vpermb")
 #define M_VPERMD FCML_TEXT("vpermd")
+#define M_VPERMI2B FCML_TEXT("vpermi2b")
+#define M_VPERMI2D FCML_TEXT("vpermi2d")
+#define M_VPERMI2PD FCML_TEXT("vpermi2pd")
+#define M_VPERMI2PS FCML_TEXT("vpermi2ps")
+#define M_VPERMI2Q FCML_TEXT("vpermi2q")
+#define M_VPERMI2W FCML_TEXT("vpermi2w")
 #define M_VPERMIL2PD FCML_TEXT("vpermil2pd")
 #define M_VPERMIL2PS FCML_TEXT("vpermil2ps")
 #define M_VPERMILPD FCML_TEXT("vpermilpd")
@@ -1143,6 +1394,15 @@
 #define M_VPERMPD FCML_TEXT("vpermpd")
 #define M_VPERMPS FCML_TEXT("vpermps")
 #define M_VPERMQ FCML_TEXT("vpermq")
+#define M_VPERMT2B FCML_TEXT("vpermt2b")
+#define M_VPERMT2D FCML_TEXT("vpermt2d")
+#define M_VPERMT2PD FCML_TEXT("vpermt2pd")
+#define M_VPERMT2PS FCML_TEXT("vpermt2ps")
+#define M_VPERMT2Q FCML_TEXT("vpermt2q")
+#define M_VPERMT2W FCML_TEXT("vpermt2w")
+#define M_VPERMW FCML_TEXT("vpermw")
+#define M_VPEXPANDD FCML_TEXT("vpexpandd")
+#define M_VPEXPANDQ FCML_TEXT("vpexpandq")
 #define M_VPEXTRB FCML_TEXT("vpextrb")
 #define M_VPEXTRD FCML_TEXT("vpextrd")
 #define M_VPEXTRQ FCML_TEXT("vpextrq")
@@ -1177,6 +1437,8 @@
 #define M_VPINSRD FCML_TEXT("vpinsrd")
 #define M_VPINSRQ FCML_TEXT("vpinsrq")
 #define M_VPINSRW FCML_TEXT("vpinsrw")
+#define M_VPLZCNTD FCML_TEXT("vplzcntd")
+#define M_VPLZCNTQ FCML_TEXT("vplzcntq")
 #define M_VPMACSDD FCML_TEXT("vpmacsdd")
 #define M_VPMACSDQH FCML_TEXT("vpmacsdqh")
 #define M_VPMACSDQL FCML_TEXT("vpmacsdql")
@@ -1189,6 +1451,8 @@
 #define M_VPMACSWW FCML_TEXT("vpmacsww")
 #define M_VPMADCSSWD FCML_TEXT("vpmadcsswd")
 #define M_VPMADCSWD FCML_TEXT("vpmadcswd")
+#define M_VPMADD52HUQ FCML_TEXT("vpmadd52huq")
+#define M_VPMADD52LUQ FCML_TEXT("vpmadd52luq")
 #define M_VPMADDUBSW FCML_TEXT("vpmaddubsw")
 #define M_VPMADDWD FCML_TEXT("vpmaddwd")
 #define M_VPMASKMOV FCML_TEXT("vpmaskmov")
@@ -1196,23 +1460,53 @@
 #define M_VPMASKMOVQ FCML_TEXT("vpmaskmovq")
 #define M_VPMAXSB FCML_TEXT("vpmaxsb")
 #define M_VPMAXSD FCML_TEXT("vpmaxsd")
+#define M_VPMAXSQ FCML_TEXT("vpmaxsq")
 #define M_VPMAXSW FCML_TEXT("vpmaxsw")
 #define M_VPMAXUB FCML_TEXT("vpmaxub")
 #define M_VPMAXUD FCML_TEXT("vpmaxud")
+#define M_VPMAXUQ FCML_TEXT("vpmaxuq")
 #define M_VPMAXUW FCML_TEXT("vpmaxuw")
 #define M_VPMINSB FCML_TEXT("vpminsb")
 #define M_VPMINSD FCML_TEXT("vpminsd")
+#define M_VPMINSQ FCML_TEXT("vpminsq")
 #define M_VPMINSW FCML_TEXT("vpminsw")
 #define M_VPMINUB FCML_TEXT("vpminub")
 #define M_VPMINUD FCML_TEXT("vpminud")
+#define M_VPMINUQ FCML_TEXT("vpminuq")
 #define M_VPMINUW FCML_TEXT("vpminuw")
+#define M_VPMOVB2M FCML_TEXT("vpmovb2m")
+#define M_VPMOVD2M FCML_TEXT("vpmovd2m")
+#define M_VPMOVDB FCML_TEXT("vpmovdb")
+#define M_VPMOVDW FCML_TEXT("vpmovdw")
+#define M_VPMOVM2B FCML_TEXT("vpmovm2b")
+#define M_VPMOVM2D FCML_TEXT("vpmovm2d")
+#define M_VPMOVM2Q FCML_TEXT("vpmovm2q")
+#define M_VPMOVM2W FCML_TEXT("vpmovm2w")
 #define M_VPMOVMSKB FCML_TEXT("vpmovmskb")
+#define M_VPMOVQ2M FCML_TEXT("vpmovq2m")
+#define M_VPMOVQB FCML_TEXT("vpmovqb")
+#define M_VPMOVQD FCML_TEXT("vpmovqd")
+#define M_VPMOVQW FCML_TEXT("vpmovqw")
+#define M_VPMOVSDB FCML_TEXT("vpmovsdb")
+#define M_VPMOVSDW FCML_TEXT("vpmovsdw")
+#define M_VPMOVSQB FCML_TEXT("vpmovsqb")
+#define M_VPMOVSQD FCML_TEXT("vpmovsqd")
+#define M_VPMOVSQW FCML_TEXT("vpmovsqw")
+#define M_VPMOVSWB FCML_TEXT("vpmovswb")
 #define M_VPMOVSXBD FCML_TEXT("vpmovsxbd")
 #define M_VPMOVSXBQ FCML_TEXT("vpmovsxbq")
 #define M_VPMOVSXBW FCML_TEXT("vpmovsxbw")
 #define M_VPMOVSXDQ FCML_TEXT("vpmovsxdq")
 #define M_VPMOVSXWD FCML_TEXT("vpmovsxwd")
 #define M_VPMOVSXWQ FCML_TEXT("vpmovsxwq")
+#define M_VPMOVUSDB FCML_TEXT("vpmovusdb")
+#define M_VPMOVUSDW FCML_TEXT("vpmovusdw")
+#define M_VPMOVUSQB FCML_TEXT("vpmovusqb")
+#define M_VPMOVUSQD FCML_TEXT("vpmovusqd")
+#define M_VPMOVUSQW FCML_TEXT("vpmovusqw")
+#define M_VPMOVUSWB FCML_TEXT("vpmovuswb")
+#define M_VPMOVW2M FCML_TEXT("vpmovw2m")
+#define M_VPMOVWB FCML_TEXT("vpmovwb")
 #define M_VPMOVZXBD FCML_TEXT("vpmovzxbd")
 #define M_VPMOVZXBQ FCML_TEXT("vpmovzxbq")
 #define M_VPMOVZXBW FCML_TEXT("vpmovzxbw")
@@ -1224,15 +1518,31 @@
 #define M_VPMULHUW FCML_TEXT("vpmulhuw")
 #define M_VPMULHW FCML_TEXT("vpmulhw")
 #define M_VPMULLD FCML_TEXT("vpmulld")
+#define M_VPMULLQ FCML_TEXT("vpmullq")
 #define M_VPMULLW FCML_TEXT("vpmullw")
+#define M_VPMULTISHIFTQB FCML_TEXT("vpmultishiftqb")
 #define M_VPMULUDQ FCML_TEXT("vpmuludq")
 #define M_VPOR FCML_TEXT("vpor")
+#define M_VPORD FCML_TEXT("vpord")
+#define M_VPORQ FCML_TEXT("vporq")
 #define M_VPPERM FCML_TEXT("vpperm")
+#define M_VPROLD FCML_TEXT("vprold")
+#define M_VPROLQ FCML_TEXT("vprolq")
+#define M_VPROLVD FCML_TEXT("vprolvd")
+#define M_VPROLVQ FCML_TEXT("vprolvq")
+#define M_VPRORD FCML_TEXT("vprord")
+#define M_VPRORQ FCML_TEXT("vprorq")
+#define M_VPRORVD FCML_TEXT("vprorvd")
+#define M_VPRORVQ FCML_TEXT("vprorvq")
 #define M_VPROTB FCML_TEXT("vprotb")
 #define M_VPROTD FCML_TEXT("vprotd")
 #define M_VPROTQ FCML_TEXT("vprotq")
 #define M_VPROTW FCML_TEXT("vprotw")
 #define M_VPSADBW FCML_TEXT("vpsadbw")
+#define M_VPSCATTERDD FCML_TEXT("vpscatterdd")
+#define M_VPSCATTERDQ FCML_TEXT("vpscatterdq")
+#define M_VPSCATTERQD FCML_TEXT("vpscatterqd")
+#define M_VPSCATTERQQ FCML_TEXT("vpscatterqq")
 #define M_VPSHAB FCML_TEXT("vpshab")
 #define M_VPSHAD FCML_TEXT("vpshad")
 #define M_VPSHAQ FCML_TEXT("vpshaq")
@@ -1253,15 +1563,20 @@
 #define M_VPSLLQ FCML_TEXT("vpsllq")
 #define M_VPSLLVD FCML_TEXT("vpsllvd")
 #define M_VPSLLVQ FCML_TEXT("vpsllvq")
+#define M_VPSLLVW FCML_TEXT("vpsllvw")
 #define M_VPSLLW FCML_TEXT("vpsllw")
 #define M_VPSRAD FCML_TEXT("vpsrad")
+#define M_VPSRAQ FCML_TEXT("vpsraq")
 #define M_VPSRAVD FCML_TEXT("vpsravd")
+#define M_VPSRAVQ FCML_TEXT("vpsravq")
+#define M_VPSRAVW FCML_TEXT("vpsravw")
 #define M_VPSRAW FCML_TEXT("vpsraw")
 #define M_VPSRLD FCML_TEXT("vpsrld")
 #define M_VPSRLDQ FCML_TEXT("vpsrldq")
 #define M_VPSRLQ FCML_TEXT("vpsrlq")
 #define M_VPSRLVD FCML_TEXT("vpsrlvd")
 #define M_VPSRLVQ FCML_TEXT("vpsrlvq")
+#define M_VPSRLVW FCML_TEXT("vpsrlvw")
 #define M_VPSRLW FCML_TEXT("vpsrlw")
 #define M_VPSUBB FCML_TEXT("vpsubb")
 #define M_VPSUBD FCML_TEXT("vpsubd")
@@ -1271,7 +1586,17 @@
 #define M_VPSUBUSB FCML_TEXT("vpsubusb")
 #define M_VPSUBUSW FCML_TEXT("vpsubusw")
 #define M_VPSUBW FCML_TEXT("vpsubw")
+#define M_VPTERNLOGD FCML_TEXT("vpternlogd")
+#define M_VPTERNLOGQ FCML_TEXT("vpternlogq")
 #define M_VPTEST FCML_TEXT("vptest")
+#define M_VPTESTMB FCML_TEXT("vptestmb")
+#define M_VPTESTMD FCML_TEXT("vptestmd")
+#define M_VPTESTMQ FCML_TEXT("vptestmq")
+#define M_VPTESTMW FCML_TEXT("vptestmw")
+#define M_VPTESTNMB FCML_TEXT("vptestnmb")
+#define M_VPTESTNMD FCML_TEXT("vptestnmd")
+#define M_VPTESTNMQ FCML_TEXT("vptestnmq")
+#define M_VPTESTNMW FCML_TEXT("vptestnmw")
 #define M_VPUNPCKHBW FCML_TEXT("vpunpckhbw")
 #define M_VPUNPCKHDQ FCML_TEXT("vpunpckhdq")
 #define M_VPUNPCKHQDQ FCML_TEXT("vpunpckhqdq")
@@ -1281,14 +1606,64 @@
 #define M_VPUNPCKLQDQ FCML_TEXT("vpunpcklqdq")
 #define M_VPUNPCKLWD FCML_TEXT("vpunpcklwd")
 #define M_VPXOR FCML_TEXT("vpxor")
+#define M_VPXORD FCML_TEXT("vpxord")
+#define M_VPXORQ FCML_TEXT("vpxorq")
+#define M_VRANGEPD FCML_TEXT("vrangepd")
+#define M_VRANGEPS FCML_TEXT("vrangeps")
+#define M_VRANGESD FCML_TEXT("vrangesd")
+#define M_VRANGESS FCML_TEXT("vrangess")
+#define M_VRCP14PD FCML_TEXT("vrcp14pd")
+#define M_VRCP14PS FCML_TEXT("vrcp14ps")
+#define M_VRCP14SD FCML_TEXT("vrcp14sd")
+#define M_VRCP14SS FCML_TEXT("vrcp14ss")
+#define M_VRCP28PD FCML_TEXT("vrcp28pd")
+#define M_VRCP28PS FCML_TEXT("vrcp28ps")
+#define M_VRCP28SD FCML_TEXT("vrcp28sd")
+#define M_VRCP28SS FCML_TEXT("vrcp28ss")
 #define M_VRCPPS FCML_TEXT("vrcpps")
 #define M_VRCPSS FCML_TEXT("vrcpss")
+#define M_VREDUCEPD FCML_TEXT("vreducepd")
+#define M_VREDUCEPS FCML_TEXT("vreduceps")
+#define M_VREDUCESD FCML_TEXT("vreducesd")
+#define M_VREDUCESS FCML_TEXT("vreducess")
+#define M_VRNDSCALEPD FCML_TEXT("vrndscalepd")
+#define M_VRNDSCALEPS FCML_TEXT("vrndscaleps")
+#define M_VRNDSCALESD FCML_TEXT("vrndscalesd")
+#define M_VRNDSCALESS FCML_TEXT("vrndscaless")
 #define M_VROUNDPD FCML_TEXT("vroundpd")
 #define M_VROUNDPS FCML_TEXT("vroundps")
 #define M_VROUNDSD FCML_TEXT("vroundsd")
 #define M_VROUNDSS FCML_TEXT("vroundss")
+#define M_VRSQRT14PD FCML_TEXT("vrsqrt14pd")
+#define M_VRSQRT14PS FCML_TEXT("vrsqrt14ps")
+#define M_VRSQRT14SD FCML_TEXT("vrsqrt14sd")
+#define M_VRSQRT14SS FCML_TEXT("vrsqrt14ss")
+#define M_VRSQRT28PD FCML_TEXT("vrsqrt28pd")
+#define M_VRSQRT28PS FCML_TEXT("vrsqrt28ps")
+#define M_VRSQRT28SD FCML_TEXT("vrsqrt28sd")
+#define M_VRSQRT28SS FCML_TEXT("vrsqrt28ss")
 #define M_VRSQRTPS FCML_TEXT("vrsqrtps")
 #define M_VRSQRTSS FCML_TEXT("vrsqrtss")
+#define M_VSCALEFPD FCML_TEXT("vscalefpd")
+#define M_VSCALEFPS FCML_TEXT("vscalefps")
+#define M_VSCALEFSD FCML_TEXT("vscalefsd")
+#define M_VSCALEFSS FCML_TEXT("vscalefss")
+#define M_VSCATTERDPD FCML_TEXT("vscatterdpd")
+#define M_VSCATTERDPS FCML_TEXT("vscatterdps")
+#define M_VSCATTERPF0DPD FCML_TEXT("vscatterpf0dpd")
+#define M_VSCATTERPF0DPS FCML_TEXT("vscatterpf0dps")
+#define M_VSCATTERPF0QPD FCML_TEXT("vscatterpf0qpd")
+#define M_VSCATTERPF0QPS FCML_TEXT("vscatterpf0qps")
+#define M_VSCATTERPF1DPD FCML_TEXT("vscatterpf1dpd")
+#define M_VSCATTERPF1DPS FCML_TEXT("vscatterpf1dps")
+#define M_VSCATTERPF1QPD FCML_TEXT("vscatterpf1qpd")
+#define M_VSCATTERPF1QPS FCML_TEXT("vscatterpf1qps")
+#define M_VSCATTERQPD FCML_TEXT("vscatterqpd")
+#define M_VSCATTERQPS FCML_TEXT("vscatterqps")
+#define M_VSHUFF32X4 FCML_TEXT("vshuff32x4")
+#define M_VSHUFF64X2 FCML_TEXT("vshuff64x2")
+#define M_VSHUFI32X4 FCML_TEXT("vshufi32x4")
+#define M_VSHUFI64X2 FCML_TEXT("vshufi64x2")
 #define M_VSHUFPD FCML_TEXT("vshufpd")
 #define M_VSHUFPS FCML_TEXT("vshufps")
 #define M_VSQRTPD FCML_TEXT("vsqrtpd")
